@@ -84,7 +84,7 @@ set_form( int numb )
         cur_form = forms[ numb ].form;
         set_bounding_box( 0, 0, cur_form->w, cur_form->h );
         fl_select_browser_line( fd_control->formbrowser, numb + 1 );
-        fl_winstepsize( main_window, 1, 1 );
+        fl_winstepunit( main_window, 1, 1 );
         fl_winresize( main_window, cur_form->w, cur_form->h );
         if ( fl_display )
             XSync( fl_display, 0 );
@@ -195,7 +195,10 @@ addform_cb( FL_OBJECT * obj  FL_UNUSED_ARG,
         goto get_new_form_name;
     }
 
-    for ( sp = s + 1; *sp; sp++ )
+    sp = s + 1;
+
+    while ( *sp )
+    {
         if (    ! isascii( ( unsigned char ) *sp )
              || ! ( isalnum( ( unsigned char ) *sp ) || *sp == '_' ) )
         {
@@ -203,6 +206,8 @@ addform_cb( FL_OBJECT * obj  FL_UNUSED_ARG,
                            "name:", s, 0 );
             goto get_new_form_name;
         }
+        sp++;
+    }
 
     /* Create the form */
 
@@ -258,14 +263,19 @@ changename_cb( FL_OBJECT * obj  FL_UNUSED_ARG,
         goto get_changed_form_name;
     }
 
-    for ( sp = s + 1; *sp; sp++ )
+    sp = s + 1;
+
+    while ( *sp )
+    {
         if (    ! isascii( ( unsigned char ) *sp )
-             || ! ( isalnum( ( unsigned char ) *sp ) || *sp == '_' ) )
+             || ! ( isalnum( ( unsigned char ) *sp ) || *s == '_' ) )
         {
             fl_show_alert( "Error", "Invalid C identifier specified for form "
                            "name:", s, 0 );
             goto get_changed_form_name;
         }
+        sp++;
+    }
 
     fli_sstrcpy( forms[ fn ].fname, s, MAX_VAR_LEN );
 
