@@ -760,7 +760,7 @@ typedef struct {
     int              direction;
     int              mbuttons;
     int              int_val;
-    unsigned int     how_return;
+    int              how_return;
     int              align;
     int              dx,
                      dy;
@@ -866,14 +866,14 @@ extern char *get_helper( char * );
 extern void setup_how_return_menu( FL_OBJECT * );
 
 extern void reset_how_return_menu( FL_OBJECT *,
-                                   unsigned int );
+                                   int );
 
 extern void handle_how_return_changes( FL_OBJECT *,
                                        FL_OBJECT * );
 
 extern int get_how_return_val( const char * );
 
-extern const char * get_how_return_name( unsigned int,
+extern const char * get_how_return_name( int,
                                          int );
 
 
