@@ -274,8 +274,8 @@ compute_selbox( float * x,
                 float * h )
 {
     int i;
-    float x1 =   1.0e+37,
-          y1 =   1.0e+37,
+    float x1 = 1.0e+37,
+          y1 = 1.0e+37,
           x2 = - 1.0e+37,
           y2 = - 1.0e+37;
 
@@ -747,64 +747,70 @@ handle_select( const XEvent * xev )
     float x,
           y,
           w,
-          h;
+          h,
+          mx,
+          my;
     float stepsize;
 
-    if ( cur_form == NULL || ! ( mouseobj = find_mouseobj( ) ) )
+    if ( cur_form == NULL )
         return;
 
-    if ( ( s = ShiftIsDown( xev->xbutton.state ) ) )      /* Shift Push */
+    s = ShiftIsDown( xev->xbutton.state );
+
+    mouseobj = find_mouseobj( );
+    find_mousepos( &mx, &my );
+
+    if ( s )            /* Shift Push */
     {
         if ( ! cur_form->first )
             fprintf( stderr, "something is wrong\n" );
-        if ( mouseobj == BackOBJ( ) )
+        if ( mouseobj == NULL || mouseobj == BackOBJ( ) )
             return;
 
         if ( find_selobject( mouseobj ) == -1 )
             addto_selection( mouseobj );
         else
             deletefrom_selection( mouseobj );
-
-        return;
     }
-
-    clear_selection( );
-
-    find_mousepos( &x, &y );
-    w = 0.0;
-    h = 0.0;
-
-    stepsize = get_step_size( );
-    set_step_size( 0.0 );
-    if ( xev->type != ButtonRelease )
-        scale_box( &x, &y, &w, &h );
-    set_step_size( stepsize );
-    obj = BackOBJ( )->next;
-
-    while ( obj != NULL )
+    else
     {
-        if (    obj->objclass != FL_BEGIN_GROUP
-             && obj->objclass != FL_END_GROUP
-              && obj->x >= x
-              && obj->y >= y
-              && obj->x + obj->w <= x + w
-              && obj->y + obj->h <= y + h )
-            addto_selection( obj );
+        clear_selection( );
+        x = mx;
+        y = my;
+        w = 0.0;
+        h = 0.0;
+        stepsize = get_step_size( );
+        set_step_size( 0.0 );
+        if ( xev->type != ButtonRelease )
+            scale_box( &x, &y, &w, &h );
+        set_step_size( stepsize );
+        obj = BackOBJ( )->next;
 
-        obj = obj->next;
-    }
-
-    if ( selnumb == 0 )
-    {
-        if ( mouseobj == NULL )
-            return;
-        else if ( mouseobj == BackOBJ( ) )
+        while ( obj != NULL )
         {
-            addto_selection( mouseobj );
-            backf = FL_TRUE;
+            if (    obj->objclass != FL_BEGIN_GROUP
+                 && obj->objclass != FL_END_GROUP
+                 && obj->x >= x
+                 && obj->y >= y
+                 && obj->x + obj->w <= x + w
+                 && obj->y + obj->h <= y + h )
+                addto_selection( obj );
+
+            obj = obj->next;
+        }
+
+        if ( selnumb == 0 )
+        {
+            if ( mouseobj == NULL )
+                return;
+            else if ( mouseobj == BackOBJ( ) )
+            {
+                addto_selection( mouseobj );
+                backf = FL_TRUE;
+            }
+            else
+                addto_selection( mouseobj );
         }
-        else
-            addto_selection( mouseobj );
     }
 }
 
@@ -1131,9 +1137,7 @@ raise_selection( void )
     for ( i = 0; i < selnumb; i++ )
     {
         fl_delete_object( selobj[ i ] );
-        if (    selobj[ i ]->objclass != FL_BEGIN_GROUP
-             && selobj[ i ]->objclass != FL_END_GROUP )
-            fl_add_object( cur_form, selobj[ i ] );
+        fl_add_object( cur_form, selobj[ i ] );
     }
 
     changed = 1;
@@ -1169,7 +1173,7 @@ lower_selection( void )
 
 
 static FL_OBJECT *cutbuf[ MAXSEL ]; /* Buffered objects */
-static int ncut = 0;                /* and their number */
+static int ncut = 0;        /* Their number */
 
 /***************************************
  ***************************************/
@@ -1225,7 +1229,7 @@ cut_selection( void )
 
 
 /***************************************
- * Pastes elements from buffer into form
+ * Pastes elements form buffer into form
  ***************************************/
 
 void
@@ -1253,10 +1257,6 @@ paste_selection(void)
 
     for ( i = 0; i < ncut; i++ )
     {
-        if (    selobj[ i ]->objclass == FL_BEGIN_GROUP
-             || selobj[ i ]->objclass == FL_END_GROUP )
-            continue;
-
         obj = copy_object( cutbuf[ i ], 1 );
 
         /* Fix label:  if underlining caused by cutbuf shortcut, remove it.
@@ -1317,7 +1317,7 @@ paste_selection(void)
 
 
 /***************************************
- * Copies all elements in the selection to the buffer
+ * Copies all elements in the selection  to the buffer
  ***************************************/
 
 void
@@ -1401,9 +1401,7 @@ set_selection( void *a )
     for ( selnumb = 0; ob[ selnumb ]; selnumb++ )
     {
         obj = copy_object( ob[ selnumb ], 1 );
-        if (    selobj[ i ]->objclass != FL_BEGIN_GROUP
-             && selobj[ i ]->objclass != FL_END_GROUP )
-            fl_add_object( cur_form, obj );
+        fl_add_object( cur_form, obj );
         selobj[ selnumb ] = obj;
     }
 
@@ -1489,14 +1487,19 @@ group_selection( void )
         goto get_new_group_name;
     }
 
-    for ( sp = s + 1; *sp; sp++ )
+    sp = s + 1;
+
+    while ( *sp )
+    {
         if (    ! isascii( ( unsigned char ) *sp )
-             || ! ( isalnum( ( unsigned char ) *sp ) || *sp == '_' ) )
+             || ! ( isalnum( ( unsigned char ) *sp ) || *s == '_' ) )
         {
             fl_show_alert( "Error", "Invalid C identifier specified for group "
                            "name:", s, 0 );
             goto get_new_group_name;
         }
+        sp++;
+    }
 
     obj = add_an_object( FL_BEGIN_GROUP, -1, 0, 0, 0, 0 );
 
