@@ -113,12 +113,12 @@ compute_rounded_corners( FL_Coord   x,
  ***************************************/
 
 void
-flps_roundrectangle( int      fill,
-                     int      x,
-                     int      y,
-                     int      w,
-                     int      h,
-                     FL_COLOR col )
+flps_roundrectangle( int  fill,
+                     int  x,
+                     int  y,
+                     int  w,
+                     int  h,
+                     long col )
 {
     FL_POINT point[ 5 * RN ];
     int n;
@@ -138,13 +138,13 @@ flps_roundrectangle( int      fill,
  *************************************************************{***/
 
 static void
-flps_roundedbox( int      style,
-                 int      x,
-                 int      y,
-                 int      w,
-                 int      h,
-                 FL_COLOR col,
-                 int      bw )
+flps_roundedbox( int  style,
+                 int  x,
+                 int  y,
+                 int  w,
+                 int  h,
+                 long col,
+                 int bw )
 {
     FL_POINT point[ 5 * RN + 2 ];
     int n,
@@ -182,13 +182,13 @@ flps_roundedbox( int      style,
  ***************************************/
 
 static void
-flps_ovalbox( int      style,
-              int      x,
-              int      y,
-              int      w,
-              int      h,
-              FL_COLOR col,
-              int      bw )
+flps_ovalbox( int  style,
+              int  x,
+              int  y,
+              int  w,
+              int  h,
+              long col,
+              int  bw )
 {
     int lw = FL_abs( bw ),
         cr = lw / 2;
@@ -270,18 +270,20 @@ flps_ovalbox( int      style,
         AddVertex( xp, x3, y3);         \
     } while ( 0 )
 
+#define Corner   4
+
 
 /***************************************
  ***************************************/
 
 static void
-flps_foldertab_box( int      style,
-                    int      x,
-                    int      y,
-                    int      w,
-                    int      h,
-                    FL_COLOR col,
-                    int      bw )
+flps_foldertab_box( int  style,
+                    int  x,
+                    int  y,
+                    int  w,
+                    int  h,
+                    long col,
+                    int  bw )
 {
     float ctr,
           right,
@@ -291,7 +293,7 @@ flps_foldertab_box( int      style,
     int border,
         i;
     float absbw = FL_abs( bw );
-    float C = 4;
+    float C = Corner;
     int savelw = fl_get_linewidth( );
 
     if ( ! ( border = bw > 0 ) )
@@ -310,13 +312,13 @@ flps_foldertab_box( int      style,
     switch ( style )
     {
         case FL_TOPTAB_UPBOX :
-            vv3( x,         y,           x, top - C, x + C, top );
-            vv2( x + C,     top, right - C, top );
-            vv3( right - C, top, right,     top - C, right, y );
+            vv3( x, y, x, top - C, x + C, top );
+            vv2( x + C, top, right - C, top );
+            vv3( right - C, top, right, top - C, right, y );
             flps_poly( 1, vert, 8, col );
             flps_linewidth( absbw );
-            flps_lines( vert,     3, FL_LEFT_BCOL   );
-            flps_lines( vert + 3, 2, FL_TOP_BCOL    );
+            flps_lines( vert, 3, FL_LEFT_BCOL );
+            flps_lines( vert + 3, 2, FL_TOP_BCOL );
             flps_lines( vert + 5, 3, FL_BOTTOM_BCOL );
             flps_reset_linewidth( );
 
@@ -334,13 +336,13 @@ flps_foldertab_box( int      style,
             break;
 
         case FL_SELECTED_TOPTAB_UPBOX :
-            vv3( x,         y - absbw, x,          top - C, x + C, top );
-            vv2( x + C,     top,       right - C,  top );
-            vv3( right - C, top,       right,      top - C, right, y - absbw );
+            vv3( x, y - absbw, x, top - C, x + C, top );
+            vv2( x + C, top, right - C, top );
+            vv3( right - C, top, right, top - C, right, y - absbw );
             flps_poly( 1, vert, 8, col );
             flps_linewidth( absbw );
-            flps_lines( vert,     3, FL_LEFT_BCOL   );
-            flps_lines( vert + 3, 2, FL_TOP_BCOL    );
+            flps_lines( vert, 3, FL_LEFT_BCOL );
+            flps_lines( vert + 3, 2, FL_TOP_BCOL );
             flps_lines( vert + 5, 3, FL_BOTTOM_BCOL );
             break;
 
@@ -365,13 +367,13 @@ flps_foldertab_box( int      style,
  ***************************************/
 
 void
-flps_draw_tbox( int      style,
-                int      x,
-                int      y,
-                int      w,
-                int      h,
-                FL_COLOR col,
-                int      bw )
+flps_draw_tbox( int  style,
+                int  x,
+                int  y,
+                int  w,
+                int  h,
+                long col,
+                int  bw )
 {
     FL_POINT point[ 8 ],
              *fp;
@@ -450,13 +452,13 @@ flps_draw_tbox( int      style,
  ***************************************/
 
 void
-flps_draw_box( int      style,
-               int      x,
-               int      y,
-               int      w,
-               int      h,
-               FL_COLOR col,
-               int      bw_in )
+flps_draw_box( int  style,
+               int  x,
+               int  y,
+               int  w,
+               int  h,
+               long col,
+               int  bw_in )
 {
     int border,
         B;
@@ -609,13 +611,13 @@ flps_draw_box( int      style,
  ***************************************/
 
 void
-flps_draw_frame( int      style,
-                 int      x,
-                 int      y,
-                 int      w,
-                 int      h,
-                 FL_COLOR col  FL_UNUSED_ARG,
-                 int      bw )
+flps_draw_frame( int  style,
+                 int  x,
+                 int  y,
+                 int  w,
+                 int  h,
+                 long col  FL_UNUSED_ARG,
+                 int  bw )
 {
     int border;
     int B;
@@ -698,13 +700,13 @@ flps_draw_frame( int      style,
  ***************************************/
 
 void
-flps_draw_checkbox( int      type,
-                    int      x,
-                    int      y,
-                    int      w,
-                    int      h,
-                    FL_COLOR col,
-                    int      bw )
+flps_draw_checkbox( int  type,
+                    int  x,
+                    int  y,
+                    int  w,
+                    int  h,
+                    long col,
+                    int bw )
 {
     FL_POINT xpoint[ 6 ],
              *xp;
