@@ -196,6 +196,9 @@ extern void fli_print_version( int );
 
 /* from forms.c and object.c */
 
+extern FL_FORM *fli_make_form( FL_Coord,
+                               FL_Coord );
+
 extern void fli_scale_form( FL_FORM *,
                             double,
                             double );
@@ -245,10 +248,6 @@ extern FL_OBJECT *fli_find_object_backwards( FL_OBJECT *,
 extern void fli_insert_object( FL_OBJECT *,
                                FL_OBJECT * );
 
-
-extern void fli_set_object_visibility( FL_OBJECT * obj,
-                                       int         vis );
-
 /* double buffering etc. */
 
 extern void fli_free_flpixmap( FL_pixmap * );
@@ -487,9 +486,7 @@ typedef struct fli_io_event_ {
 
 /* signals */
 
-#if ! defined HAVE_SIGACTION
-typedef RETSIGTYPE ( * FLI_OSSIG_HANDLER )( int );
-#endif
+typedef RETSIGTYPE ( * FL_OSSIG_HANDLER )( int );
 
 typedef struct fli_signallist_ {
     struct fli_signallist_ * next;
@@ -497,7 +494,7 @@ typedef struct fli_signallist_ {
 #if defined HAVE_SIGACTION
     struct sigaction         old_sigact;
 #else
-    FLI_OSSIG_HANDLER        ocallback; /* default OS signal handler */
+    FL_OSSIG_HANDLER         ocallback; /* default OS signal handler */
 #endif
     void                   * data;
     int                      signum;
@@ -893,6 +890,9 @@ extern char *fli_sstrcpy( char       * dest,
                           const char * src,
                           size_t       n );
 
+extern void fli_mark_composite_for_redraw( FL_OBJECT * );
+
+
 extern void fli_set_form_icon_data( FL_FORM *,
                                     char ** );
 
@@ -1026,11 +1026,6 @@ extern FL_POPUP_ENTRY *fli_popup_insert_entries( FL_POPUP *,
                                                  const char *,
                                                  int );
 
-extern FL_POPUP_ENTRY *fli_popup_insert_items( FL_POPUP       *,
-                                               FL_POPUP_ENTRY *,
-                                               FL_POPUP_ITEM  *,
-                                               const char * );
-
 extern void fli_popup_init( void );
 
 extern void fli_popup_finish( void );
