@@ -114,8 +114,8 @@ fli_init_font( void )
 
     initialized = 1;
 
-    /* If fl_set_font_name() is called before fl_initialize(), we need to
-       keep the change */
+    /* If fl_set_font_name is called before fl_initialize, we need to keep
+       the change */
 
     for ( ; *f; f++, flf++ )
         if ( ! *flf->fname )
@@ -131,8 +131,8 @@ fli_init_font( void )
        using bad looking replacement if strange sizes are requested */
 
     fl_get_font_struct( FL_NORMAL_STYLE, FL_DEFAULT_SIZE );
-    fl_get_font_struct( FL_BOLD_STYLE,   FL_DEFAULT_SIZE );
-    fl_get_font_struct( FL_FIXED_STYLE,  FL_DEFAULT_SIZE );
+    fl_get_font_struct( FL_BOLD_STYLE, FL_DEFAULT_SIZE );
+    fl_get_font_struct( FL_FIXED_STYLE, FL_DEFAULT_SIZE );
 }
 
 
@@ -225,7 +225,7 @@ fl_set_font_name( int          n,
     flf->nsize = 0;
     strcpy( flf->fname, name );
 
-    if ( ! flx || ! flx->display )
+    if ( ! flx->display )
         return 1;
 
     return try_get_font_struct( n, FL_DEFAULT_SIZE, 1 ) ? 0 : -1;
@@ -233,7 +233,7 @@ fl_set_font_name( int          n,
 
 
 /***************************************
- * List built-in fonts
+ * list built-in fonts
  ***************************************/
 
 int
@@ -281,8 +281,8 @@ try_get_font_struct( int numb,
         if ( ! fli_no_connection ) {
 
             /* This function is typically used to test whether a font is
-               loadable or not, so need not be a fatal condition if
-               it fails. Issue a message for information therefore. */
+             * loadable or not, so need not be a fatal condition if
+             * it fails. Issue a message for information therefore. */
 
             M_info( "try_get_font_struct", "Bad FontStyle requested: %d: %s",
                     numb, flf->fname );
@@ -296,9 +296,10 @@ try_get_font_struct( int numb,
 
     strcpy( fli_curfnt, get_fname( flf->fname, size ) );
 
-    /* Search for requested size */
+    /* search for requested size */
 
-    for ( fs = NULL, i = 0; i < flf->nsize; i++ )
+    for ( fs = 0, i = 0; i < flf->nsize; i++ )
+    {
         if ( size == flf->size[ i ] )
         {
             fs = flf->fs[ i ];
@@ -307,9 +308,10 @@ try_get_font_struct( int numb,
                      fl_cur_fontname );
 #endif
         }
+    }
 
-    /* If requested font is not found or cache is full, get the destination
-       cache for this size */
+    /* if requested not found or cache full, get the destination cache for
+       this size */
 
     if ( ! fs && flf->nsize == FL_MAX_FONTSIZES )
     {
@@ -317,7 +319,7 @@ try_get_font_struct( int numb,
         flf->nsize--;
     }
 
-    /* Font is not cached, try to load the font */
+    /* font is not cached, try to load the font */
 
     if ( ! fs )
     {
@@ -332,7 +334,7 @@ try_get_font_struct( int numb,
     }
 
     if ( ! fs && with_fail )
-        return NULL;
+        return 0;
 
     /* Didn't get it. Try to find a substitute */
 
@@ -343,7 +345,7 @@ try_get_font_struct( int numb,
 
         M_warn( "try_get_font_struct", "can't load %s", fli_curfnt );
 
-        /* Search for a replacement */
+        /* search for a replacement */
 
         for ( i = 0; i < flf->nsize; i++ )
         {
@@ -635,32 +637,26 @@ cv_fname( const char *f )
 
 
 /***************************************
- * Given a font name and a size (in points), assemble the complete name
+ * Given a fontname and a size (in point), get the complete name
  ***************************************/
 
 static char *
 get_fname( const char * str,
            int          size )
 {
-    static char fname[ sizeof fli_curfnt ];
-    char len_str[ 50 ];    /* should be enough for all ints */
-    int len;
-    char *p;
+    static char fname[ 80 ];
+    char *p,
+         sz[ 15 ],
+         tail[ 80 ];
 
-    /* If necessary truncate font names that are too long, the caller
-       expects a real string */
-
-    strncpy( fname, str, sizeof fname - 1 );
-    fname[ sizeof fname - 1 ] = '\0';
+    strcpy( fname, str );
 
     if ( ( p = strchr( fname, '?' ) ) )
     {
-        len = sprintf( len_str, "%d0", size );
-        if ( len + strlen( str ) <= sizeof fname - 1 )
-        {
-            memmove( p + len, p + 1, strlen( p ) );
-            strncpy( p, len_str, len );
-        }
+        sprintf( sz, "%d", size * 10 );
+        strcpy( tail, p + 1 );
+        *p = '\0';
+        strcat( strcat( fname, sz ), tail );
     }
 
     return fname;
