@@ -57,26 +57,6 @@ static XEvent st_xev;
 extern void ( * fli_handle_signal )( void );       /* defined in signal.c */
 extern int ( * fli_handle_clipboard )( void * );   /* defined in clipboard.c */
 
-/* When set results in behaviour as in version 1.0.90 and before where
-   clicking on a non-input object didn't make an input object lose focus
-   shortly and thus no "end of editing" was signaled to the user */
-
-static int end_event_for_input = FL_INPUT_END_EVENT_ALWAYS;
-
-
-/***************************************
- * Function for switching between "old" and "new" input handling
- * when another non-input object is clicked on
- ***************************************/
-
-int
-fl_input_end_return_handling( int type )
-{
-    int old_end_event_for_input = end_event_for_input;
-
-    end_event_for_input = type;
-    return old_end_event_for_input;
-}
 
 
 /***************************************
@@ -114,13 +94,15 @@ fli_XLookupString( XKeyEvent * xkey,
 
 
 /***************************************
- * Converts 'state' member of the 'xkey' member of an XEvent
- * into the corresponding mouse button number
+ * Should pass the mask instead of button numbers into the
+ * event handler. basically throwing away info ..
  ***************************************/
 
 static int
-xmask2button( unsigned int mask )
+xmask2key( unsigned int mask )
 {
+    /* Once the FL_XXX_MOUSE is changed to mask, just loose the else */
+
     if ( mask & Button1Mask )
         return FL_LEFT_MOUSE;
 
@@ -203,30 +185,32 @@ do_shortcut( FL_FORM  * form,
     FL_OBJECT *obj;
     long *s;
 
-    key1 = key2 = key;
+    /* Check whether the <Alt> key is pressed */
 
-    /* Check for ALT modifier key */
+    key1 = key2 = key;
 
     if ( fl_keypressed( XK_Alt_L ) || fl_keypressed( XK_Alt_R ) )
     {
         if ( key < 256 )
         {
-            key1 = FL_ALT_MASK + ( islower( ( int ) key ) ?
-                                   toupper( ( int ) key ) : key );
-            key2 = FL_ALT_MASK + key;
+            /* It's always a good idea to make Alt_k case insensitive */
+
+            key1 = FL_ALT_MASK
+                   + ( islower( key ) ? toupper( key ) : tolower( key ) );
+            key2 = key + FL_ALT_MASK;
         }
         else
-            key1 = key2 = FL_ALT_MASK + key;
+            key1 = key2 = key + FL_ALT_MASK;
     }
 
     M_info( "do_shortcut", "win = %ld key = %d %d %d",
             form->window, key, key1, key2 );
 
-    /* Check if an object has this as a shortcut */
+    /* Check whether an object has this as a shortcut */
 
     for ( obj = form->first; obj; obj = obj->next )
     {
-        if ( ! obj->shortcut || ! obj->active || ! obj->visible)
+        if ( ! obj->visible || ! obj->active || ! obj->shortcut )
             continue;
 
         for ( s = obj->shortcut; *s; s++ )
@@ -254,7 +238,7 @@ do_shortcut( FL_FORM  * form,
                 fli_context->mouse_button = FL_SHORTCUT + key1;
 
                 /* This is not exactly correct as shortcut might quit,
-                   fl_finish() will restore the keyboard state */
+                   fl_finish will restore the keyboard state */
 
                 if ( fli_keybdcontrol.auto_repeat_mode == AutoRepeatModeOn )
                     XAutoRepeatOn( flx->display );
@@ -336,56 +320,61 @@ handle_keyboard( FL_FORM  * form,
                  || IsRight( key )
                  || IsHome( key )
                  || IsEnd( key ) )
-                fli_handle_object( focusobj, FL_KEYPRESS, x, y, key, xev, 1 );
+                fli_handle_object( focusobj, FL_KEYBOARD, x, y, key, xev, 1 );
             else if (    (    IsUp( key )
                            || IsDown( key )
                            || IsPageUp( key )
                            || IsPageDown( key ) )
                       && focusobj->wantkey & FL_KEY_TAB )
-                fli_handle_object( focusobj, FL_KEYPRESS, x, y, key, xev, 1 );
+                fli_handle_object( focusobj, FL_KEYBOARD, x, y, key, xev, 1 );
             else if ( special && special->wantkey & FL_KEY_SPECIAL )
             {
                 /* Moving the cursor in input field that does not have focus
                    looks weird */
 
                 if ( special->objclass != FL_INPUT )
-                    fli_handle_object( special, FL_KEYPRESS,
+                    fli_handle_object( special, FL_KEYBOARD,
                                        x, y, key, xev, 1 );
             }
             else if ( key == XK_BackSpace || key == XK_Delete )
-                fli_handle_object( focusobj, FL_KEYPRESS, x, y, key, xev, 1 );
+                fli_handle_object( focusobj, FL_KEYBOARD, x, y, key, xev, 1 );
             return;
         }
 
-        /* The <Tab> and <Return> keys move the focus to the next or previous
-           input object (depending on <SHIFT> being pressed also, and for
-           <Return> only if the current focus object hasn't set FL_KEY_TAB as
-           it's the case for  multiline input objects) */
+        /* Tab & Return switches focus (for Return only if not FL_KEY_TAB) */
 
         if (    key == '\t'
              || ( key == '\r' && ! ( focusobj->wantkey & FL_KEY_TAB ) ) )
         {
-            fli_handle_object( focusobj, FL_UNFOCUS, x, y, 0, xev, 1 );
-
             if ( ( ( XKeyEvent * ) xev )->state & fli_context->navigate_mask )
             {
-                if ( ! ( obj = fli_find_object_backwards( focusobj->prev,
-                                                          FLI_FIND_INPUT,
-                                                          0, 0 ) ) )
+                if ( focusobj == fli_find_first( form, FLI_FIND_INPUT, 0, 0 ) )
                     obj = fli_find_last( form, FLI_FIND_INPUT, 0, 0 );
+                else
+                    obj = fli_find_object_backwards( focusobj->prev,
+                                                     FLI_FIND_INPUT, 0, 0 );
             }
-            else                                      /* search forward */
+            else
+                obj = fli_find_object( focusobj->next, FLI_FIND_INPUT, 0, 0 );
+
+            if ( obj == NULL )
+                obj = fli_find_first( form, FLI_FIND_INPUT, 0, 0 );
+
+            if ( obj != NULL && obj != focusobj )
             {
-                if ( ! ( obj = fli_find_object( focusobj->next,
-                                                FLI_FIND_INPUT, 0, 0 ) ) )
-                        
-                    obj = fli_find_first( form, FLI_FIND_INPUT, 0, 0 );
+                fli_handle_object( focusobj, FL_UNFOCUS, x, y, 0, xev, 1 );
+                fli_handle_object( obj, FL_FOCUS, x, y, 0, xev, 1 );
+            }
+            else if (    key == '\r'
+                      && ( obj = fli_find_first( form, FLI_FIND_RETURN,
+                                                 0, 0 ) ) )
+            {
+                fli_handle_object( focusobj, FL_UNFOCUS, x, y, 0, xev, 1 );
+                fli_handle_object( obj, FL_SHORTCUT, x, y, key, xev, 1 );
             }
-                
-            fli_handle_object( obj, FL_FOCUS, x, y, 0, xev, 1 );
         }
         else if ( focusobj->wantkey != FL_KEY_SPECIAL )
-            fli_handle_object( focusobj, FL_KEYPRESS, x, y, key, xev, 1 );
+            fli_handle_object( focusobj, FL_KEYBOARD, x, y, key, xev, 1 );
         return;
     }
 
@@ -397,11 +386,11 @@ handle_keyboard( FL_FORM  * form,
     /* Space is an exception for browser */
 
     if ( ( key > 255 || key == ' ' ) && special->wantkey & FL_KEY_SPECIAL )
-        fli_handle_object( special, FL_KEYPRESS, x, y, key, xev, 1 );
+        fli_handle_object( special, FL_KEYBOARD, x, y, key, xev, 1 );
     else if ( key < 255 && special->wantkey & FL_KEY_NORMAL )
-        fli_handle_object( special, FL_KEYPRESS, x, y, key, xev, 1 );
+        fli_handle_object( special, FL_KEYBOARD, x, y, key, xev, 1 );
     else if ( special->wantkey == FL_KEY_ALL )
-        fli_handle_object( special, FL_KEYPRESS, x, y, key, xev, 1 );
+        fli_handle_object( special, FL_KEYBOARD, x, y, key, xev, 1 );
 
 #if FL_DEBUG >= ML_INFO1
     M_info( "handle_keyboard", "(%d %d) pushing %d to %s\n",
@@ -442,8 +431,8 @@ fli_handle_form( FL_FORM * form,
     {
         fl_get_form_mouse( fli_int.mouseform, &fli_int.mousex, &fli_int.mousey,
                            &fli_int.keymask );
-        if ( event != FL_KEYPRESS )
-            key = xmask2button( fli_int.keymask );
+        if ( event != FL_KEYBOARD )
+            key = xmask2key( fli_int.keymask );
         fli_int.query_age = 0;
     }
 
@@ -482,10 +471,7 @@ fli_handle_form( FL_FORM * form,
                FL_PUSH was for is still active - it may have become deactivated
                due to the handler for the object that became unfocused! */
 
-            if (    obj
-                 && form->focusobj
-                 && form->focusobj != obj
-                 && ( obj->input || end_event_for_input ) )
+            if ( obj && form->focusobj && form->focusobj != obj )
             {
                 FL_OBJECT *old_focusobj = form->focusobj;
 
@@ -556,11 +542,11 @@ fli_handle_form( FL_FORM * form,
 
             break;
 
-        case FL_KEYPRESS:      /* key was pressed */
+        case FL_KEYBOARD:       /* key was pressed */
             handle_keyboard( form, key, x, y, xev );
             break;
 
-        case FL_STEP:          /* simple step */
+        case FL_STEP:       /* simple step */
             obj = fli_find_first( form, FLI_FIND_AUTOMATIC, 0, 0 );
 
             if ( obj )
@@ -584,8 +570,8 @@ fli_handle_form( FL_FORM * form,
 
         case FL_MOVEORIGIN:
         case FL_OTHER:
-            /* Need to dispatch it through all objects and monitor the status
-               of forms as it may get closed */
+            /* Need to dispatch it thru all objects and monitor the status of
+               forms as it may get closed */
 
             for ( obj = form->first; obj && form->visible == FL_VISIBLE;
                   obj = obj->next )
@@ -676,7 +662,7 @@ do_keyboard( XEvent * xev,
 
 
 /***************************************
- * ClientMessage is intercepted if it's WM_DELETE_WINDOW
+ * ClientMessage is intercepted if it is delete window
  ***************************************/
 
 static void
@@ -685,7 +671,7 @@ handle_ClientMessage_event( FL_FORM * form,
 {
     XClientMessageEvent *xcm = xev;
     static Atom atom_protocol;
-    static Atom atom_del_win = None;
+    static Atom atom_del_win;
 
 
     if ( ! atom_del_win )
@@ -717,7 +703,7 @@ handle_ClientMessage_event( FL_FORM * form,
         else
             exit( 1 );
     }
-    else    /* pump it through current form */
+    else    /* pump it thru current form */
         fli_handle_form( form, FL_OTHER, 0, xev );
 }
 
@@ -727,7 +713,7 @@ static int preemptive_consumed( FL_FORM *,
                                 XEvent * );
 
 /***************************************
- * Given an X event check for which of our forms it is
+ * Given an X event check for which of our forms it is.
  ***************************************/
 
 FL_FORM *
@@ -969,13 +955,13 @@ fli_handle_idling( XEvent * xev,
          && fli_int.pushobj->want_update
          && fli_int.mouseform )
         fli_handle_form( fli_int.mouseform, FL_UPDATE,
-                         xmask2button( fli_int.keymask ), xev );
+                         xmask2key( fli_int.keymask ), xev );
 
     /* Handle automatic tasks */
 
     if ( fli_int.auto_count )
         for ( i = 0; i < fli_int.formnumb; i++ )
-            if ( fli_int.forms[ i ]->num_auto_objects )
+            if ( fli_int.forms[ i ]->has_auto_objects )
                 fli_handle_form( fli_int.forms[ i ], FL_STEP, 0, xev );
 
     /* If asked to also execute user idle callbacks */
@@ -1075,7 +1061,7 @@ handle_EnterNotify_event( FL_FORM * evform )
 
     if ( fli_int.mouseform )
         fli_handle_form( fli_int.mouseform, FL_LEAVE,
-                         xmask2button( fli_int.keymask ), &st_xev );
+                         xmask2key( fli_int.keymask ), &st_xev );
 
     if ( evform )
     {
@@ -1093,7 +1079,7 @@ handle_EnterNotify_event( FL_FORM * evform )
         }
 
         fli_handle_form( fli_int.mouseform, FL_ENTER,
-                         xmask2button( fli_int.keymask ), &st_xev );
+                         xmask2key( fli_int.keymask ), &st_xev );
     }
 #if FL_DEBUG >= ML_DEBUG
     else
@@ -1119,7 +1105,7 @@ handle_LeaveNotify_event( void )
         return;
 
     /* olvwm sends LeaveNotify with NotifyGrab whenever button is clicked,
-       ignore it. Due to Xpopup grab, (maybe Wm bug?), end grab can also
+       ignore it. Due to Xpopup grab, (maybe Wm bug ?), end grab can also
        generate this event. We can tell these two situations by doing a real
        button_down test (as opposed to relying on the keymask in event) */
 
@@ -1130,7 +1116,7 @@ handle_LeaveNotify_event( void )
         return;
 
     fli_handle_form( fli_int.mouseform, FL_LEAVE,
-                     xmask2button( fli_int.keymask ), &st_xev );
+                     xmask2key( fli_int.keymask ), &st_xev );
 }
 
 
@@ -1163,7 +1149,7 @@ handle_MotionNotify_event( FL_FORM * evform )
     }
 
     fli_handle_form( fli_int.mouseform, FL_MOTION,
-                     xmask2button( fli_int.keymask ), &st_xev );
+                     xmask2key( fli_int.keymask ), &st_xev );
 }
 
 
@@ -1331,7 +1317,7 @@ fl_check_only_forms( void )
 
 
 /***************************************
- * Checks all forms and keeps checking as long as nothing happens.
+ * Checks all forms and keep checking while nothing happens.
  ***************************************/
 
 FL_OBJECT *
@@ -1516,7 +1502,7 @@ add_idle_callback( FL_APPEVENT_CB   cb,
 
 
 /***************************************
- * Sets an idle callback
+ * Set an idle callback
  ***************************************/
 
 FL_APPEVENT_CB
