@@ -144,9 +144,11 @@ FL_EXPORT int fl_mode_capable( int mode,
 #define fl_default_window( )    ( fl_state[ fl_vmode ].trailblazer )
 
 
-/* All pixmaps used by FL_OBJECT to simulate double buffering have the
+/*
+ * All pixmaps used by FL_OBJECT to simulate double buffering have the
  * following entries in the structure. FL_Coord x,y are used to shift
- * the origin of the drawing routines */
+ * the origin of the drawing routines
+ */
 
 struct FL_pixmap_ {
     Pixmap         pixmap;
@@ -388,14 +390,21 @@ FL_EXPORT int fl_get_decoration_sizes( FL_FORM * form,
                                        int     * bottom,
                                        int     * left );
 
-FL_EXPORT void fl_raise_form( FL_FORM * form );
+#define fl_raise_form( f )                           \
+    do { if ( f->window )                            \
+             XRaiseWindow( fl_display, f->window );  \
+    } while( 0 )
 
-FL_EXPORT void fl_lower_form( FL_FORM * form );
+#define fl_lower_form( f )                           \
+    do { if ( f->window )                            \
+             XLowerWindow( fl_display, f->window );  \
+    } while( 0 )
 
-FL_EXPORT void fl_set_foreground( GC       gc,
-								  FL_COLOR color );
-FL_EXPORT void fl_set_background( GC       gc,
-								  FL_COLOR color );
+#define fl_set_foreground( gc, c )   \
+    XSetForeground( fl_display, gc, fl_get_pixel( c ) )
+
+#define fl_set_background( gc, c )   \
+    XSetBackground( fl_display, gc, fl_get_pixel( c ) )
 
 /* General windowing support */
 
@@ -441,7 +450,7 @@ FL_EXPORT void fl_winicon( Window win,
 FL_EXPORT void fl_winbackground( Window   win,
                                  FL_COLOR bk );
 
-FL_EXPORT void fl_winstepsize( Window   win,
+FL_EXPORT void fl_winstepunit( Window   win,
                                FL_Coord dx,
                                FL_Coord dy );
 
@@ -458,8 +467,7 @@ FL_EXPORT void fl_winposition( FL_Coord x,
 
 #define fl_pref_winposition   fl_winposition
 #define fl_win_background     fl_winbackground
-#define fl_winstepunit        fl_winstepsize
-#define fl_set_winstepunit    fl_winstepsize
+#define fl_set_winstepunit    fl_winstepunit
 
 FL_EXPORT void fl_winminsize( Window   win,
                               FL_Coord w,
@@ -556,7 +564,7 @@ FL_EXPORT Window fl_get_real_object_window( FL_OBJECT * ob );
                         | PointerMotionMask )
 
 
-/* Replacements for X functions that access the event queue */
+/* Replacements for X functions that access the event queue*/
 
 FL_EXPORT int fl_XNextEvent( XEvent * xev );
 
@@ -599,8 +607,6 @@ FL_EXPORT void fl_activate_event_callbacks( Window win );
 FL_EXPORT XEvent *fl_print_xevent_name( const char   * where,
                                         const XEvent * xev );
 
-FL_EXPORT void fl_XFlush( void );
-
 #define metakey_down( mask )     ( ( mask ) & Mod1Mask )
 #define shiftkey_down( mask )    ( ( mask ) & ShiftMask )
 #define controlkey_down( mask )  ( ( mask ) & ControlMask )
@@ -804,7 +810,7 @@ typedef unsigned int       FL_PACKED4;
 
 /* If PCBITS is not 8, we need to apply the RGBmask */
 
-#define FL_GETR( packed )  ( ( ( packed ) >> FL_RSHIFT ) & FL_RMASK )
+#define FL_GETR( packed )  ( ( packed ) & FL_RMASK )
 #define FL_GETG( packed )  ( ( ( packed ) >> FL_GSHIFT ) & FL_PCMAX )
 #define FL_GETB( packed )  ( ( ( packed ) >> FL_BSHIFT ) & FL_PCMAX )
 #define FL_GETA( packed )  ( ( ( packed ) >> FL_ASHIFT ) & FL_PCMAX )
