@@ -26,16 +26,15 @@
 
 static int handle_nmenu( FL_OBJECT *, int, FL_Coord, FL_Coord,
                          int , void * );
+static void popup_reparent( FL_POPUP *, FL_POPUP * );
 static void draw_menu( FL_OBJECT * );
 
 
-#define IS_TOUCH_NMENU( o )                      \
-	(    ( o )->type == FL_NORMAL_TOUCH_NMENU    \
-      || ( o )->type == FL_BUTTON_TOUCH_NMENU )
+#define IS_TOUCH_NMENU( o )  \
+( ( o )->type == FL_NORMAL_TOUCH_NMENU || ( o )->type == FL_BUTTON_TOUCH_NMENU )
 
-#define IS_BUTTON_NMENU( o )                     \
-	(    ( o )->type == FL_BUTTON_NMENU          \
-      || ( o )->type == FL_BUTTON_TOUCH_NMENU )
+#define IS_BUTTON_NMENU( o )  \
+( ( o )->type == FL_BUTTON_NMENU || ( o )->type == FL_BUTTON_TOUCH_NMENU )
 
 
 /***************************************
@@ -139,7 +138,7 @@ fl_clear_nmenu( FL_OBJECT * obj )
 
 
 /***************************************
- * Add (append) item(s) to the nmenu object
+ * Add item(s) to the nmenu object
  ***************************************/
 
 FL_POPUP_ENTRY *
@@ -237,7 +236,7 @@ fl_replace_nmenu_item( FL_OBJECT      * obj,
 
     if ( ! items || ! *items )
     {
-        M_err( "fl_replace_nmenu_item", "Items string NULL or empty" );
+        M_err( "fl_replace_nmenu_items", "Items string NULL or empty" );
         return NULL;
     }
 
@@ -251,7 +250,7 @@ fl_replace_nmenu_item( FL_OBJECT      * obj,
 
     if ( fli_check_popup_entry_exists( old_item ) )
     {
-        M_err( "fl_replace_nmenu_item", "Item to replace doesn't exist" );
+        M_err( "fl_replace_nmenu_items", "Item to replace doesn't exist" );
         return NULL;
     }
 
@@ -259,7 +258,7 @@ fl_replace_nmenu_item( FL_OBJECT      * obj,
 
     va_start( ap, items );
     new_entries = fli_popup_insert_entries( sp->popup, old_item, items, ap,
-                                            "fl_replace_nmenu_item", 0 );
+                                            "fl_replace_nmenu_items", 0 );
     va_end( ap );
 
     /* If the insert worked out ok delete the old item (and check if we
@@ -322,9 +321,10 @@ fl_delete_nmenu_item( FL_OBJECT      * obj,
 
 FL_POPUP_ENTRY *
 fl_set_nmenu_items( FL_OBJECT     * obj,
-                    FL_POPUP_ITEM * items )
+                     FL_POPUP_ITEM * items )
 {
     FLI_NMENU_SPEC *sp;
+    FL_POPUP *p;
 
     if ( obj == NULL )
     {
@@ -334,171 +334,33 @@ fl_set_nmenu_items( FL_OBJECT     * obj,
 
     sp = obj->spec;
 
-    /* If no popup exists yet create it, otherwise remove all entries */
-
     if ( sp->popup == NULL )
         sp->popup = fli_popup_add( FL_ObjWin( obj ), NULL,
                                    "fl_set_nmenu_items" );
-    else
-    {
-        while ( sp->popup->entries != NULL )
-            fl_popup_entry_delete( sp->popup->entries );
 
-        fli_popup_reset_counter( sp->popup );
-    }
+    /* Create a new popup (otherwise we would have to repeat much of the
+       code from popup.c) */
+
+    if ( ( p = fl_popup_create( sp->popup->win, NULL, items ) ) == NULL )
+        return NULL;
+
+    /* Remove all existing entries and reset the popups internal counter */
+
+    while ( sp->popup->entries != NULL )
+        fl_popup_entry_delete( sp->popup->entries );
+
+    fli_popup_reset_counter( sp->popup );
+
+    /* Now move the new entries to the already existing popup of the nmenu
+       object*/
+
+    sp->popup->entries = p->entries;
+    popup_reparent( sp->popup, sp->popup );
+    fl_free( p );
 
     sp->sel = NULL;
 
-    return fli_popup_insert_items( sp->popup, NULL, items,
-                                   "fl_set_nmenu_items" );
-}
-
-
-/***************************************
- * Add (append) item(s) to the nmenu object from a list of FL_POPUP_ITEM
- * structures
- ***************************************/
-
-FL_POPUP_ENTRY *
-fl_add_nmenu_items2( FL_OBJECT     * obj,
-                     FL_POPUP_ITEM * items )
-{
-    FLI_NMENU_SPEC *sp;
-    FL_POPUP_ENTRY *after;
-    FL_POPUP_ENTRY *new_entries;
-
-    if ( obj == NULL )
-    {
-        M_err( "fl_add_nmenu_items2", "NULL object" );
-        return NULL;
-    }
-
-    if ( ! items || ! items->text )
-    {
-        M_err( "fl_add_nmenu_items2", "Items list NULL or empty" );
-        return NULL;
-    }
-
-    sp = obj->spec;
-
-    if ( sp->popup == NULL )
-        sp->popup = fli_popup_add( FL_ObjWin( obj ), NULL,
-                                   "fl_add_nmenu_items2" );
-
-    /* Determine the last existing entry in the nmenu's popup */
-
-    after = sp->popup->entries;
-    while ( after != NULL && after->next != NULL )
-        after = after->next;
-
-    /* Create and append the new entries to the popup */
-
-    new_entries = fli_popup_insert_items( sp->popup, after, items,
-                                          "fl_add_nmenu_items2" );
-
-    return new_entries;
-}
-
-
-/***************************************
- * Insert item(s) into the nmenu object from a list of FL_POPUP_ITEM
- * structures after an already existing item
- ***************************************/
-
-FL_POPUP_ENTRY *
-fl_insert_nmenu_items2( FL_OBJECT      * obj,
-                        FL_POPUP_ENTRY * after,
-                        FL_POPUP_ITEM  * items )
-{
-    FLI_NMENU_SPEC *sp;
-    FL_POPUP_ENTRY *new_entries;
-
-    if ( obj == NULL )
-    {
-        M_err( "fl_add_nmenu_items2", "NULL object" );
-        return NULL;
-    }
-
-    if ( ! items || ! items->text )
-    {
-        M_err( "fl_insert_nmenu_items2", "Items list NULL or empty" );
-        return NULL;
-    }
-
-    sp = obj->spec;
-
-    if ( sp->popup == NULL )
-        sp->popup = fli_popup_add( FL_ObjWin( obj ), NULL,
-                                   "fl_insert_nmenu_items2" );
-
-    if ( after != NULL && fli_check_popup_entry_exists( after ) != 0 )
-    {
-        M_err( "fl_add_nmenu_items2", "Item to insert after doesn't exist" );
-        return NULL;
-    }
-
-    new_entries = fli_popup_insert_items( sp->popup, after, items,
-                                          "fl_insert_nmenu_items2" );
-
-    return new_entries;
-}
-
-
-/***************************************
- * Replace an item by new item(s) from a list of FL_POPUP_ITEM structures
- ***************************************/
-
-FL_POPUP_ENTRY *
-fl_replace_nmenu_items2( FL_OBJECT      * obj,
-                         FL_POPUP_ENTRY * old_item,
-                         FL_POPUP_ITEM  * items )
-{
-    FLI_NMENU_SPEC *sp;
-    FL_POPUP_ENTRY *new_entries;
-
-    if ( obj == NULL )
-    {
-        M_err( "fl_replace_nmenu_items2", "NULL object" );
-        return NULL;
-    }
-
-    if ( ! items || ! items->text )
-    {
-        M_err( "fl_replace_nmenu_items2", "Items list NULL or empty" );
-        return NULL;
-    }
-
-    sp = obj->spec;
-
-    if ( sp->popup == NULL )
-        sp->popup = fli_popup_add( FL_ObjWin( obj ), NULL,
-                                   "fl_replace_nmenu_items2" );
-
-    /* Test if the item we're supposed to replace exists */
-
-    if ( fli_check_popup_entry_exists( old_item ) )
-    {
-        M_err( "fl_replace_nmenu_item2", "Item to replace doesn't exist" );
-        return NULL;
-    }
-
-    /* Add the new item(s) after the one to replaced */
-
-    new_entries = fli_popup_insert_items( sp->popup, old_item, items,
-                                          "fl_replace_nmenu_item2" );
-
-    /* If the insert worked out ok delete the old item (and check if we
-       have to set a new displayed item) */
-
-    if ( new_entries != NULL )
-    {
-        if ( sp->sel != NULL && sp->sel->entry == old_item )
-            sp->sel = NULL;
-
-        fl_popup_entry_delete( old_item );
-    }
-
-    return new_entries;
+    return p->entries;
 }
 
 
@@ -772,8 +634,6 @@ handle_nmenu( FL_OBJECT * obj,
 
         case FL_SHORTCUT :
         case FL_PUSH :
-            if ( ! sp->popup || ! sp->popup->entries )
-                break;
             obj->pushed = 1;
             fl_redraw_object( obj );
             fl_popup_get_size( sp->popup, &w, &h );
@@ -803,6 +663,28 @@ handle_nmenu( FL_OBJECT * obj,
 }
 
 
+/***************************************
+ ***************************************/
+
+static void
+popup_reparent( FL_POPUP * popup,
+                FL_POPUP * top_parent )
+{
+    FL_POPUP_ENTRY *e;
+
+    for ( e = popup->entries; e != NULL; e = e->next )
+    {
+        e->popup = popup;
+        if ( e->type == FL_POPUP_SUB )
+        {
+            e->sub->parent = popup;
+            e->sub->top_parent = top_parent;
+            popup_reparent( e->sub, top_parent );
+        }
+    }
+}
+
+
 /***************************************
  ***************************************/
 
