@@ -24,19 +24,6 @@
  *  All rights reserved.
  */
 
-
-/**************************************************
-
-  The handling of redrawing objects could do with a lot of improvements.
-  It should be a high priority that only that objects get redrawn that
-  rally need redrawing. The main problem at the moment is handling of
-  redraws for objects with a label outside of the object (and of objects
-  with the label inside, but extending beyond the borders of the object).
-  That's all still a mess (and too slow ) and needs quite a bit of cleaning
-   up!
-
- ***************************************************/
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -46,6 +33,11 @@
 #include <string.h>
 
 
+#define PointToPixel( a )     FL_crnd( ( a ) * fli_dpi / 72.0   )
+#define MMToPixel( a )        FL_crnd( ( a ) * fli_dpi / 25.4   )
+#define CMMToPixel( a )       FL_crnd( ( a ) * fli_dpi / 2540.0 )
+#define CPointToPixel( a )    FL_crnd( ( a ) * fli_dpi / 7200.0 )
+
 #define TRANY( obj, form )    ( form->h - obj->h - obj->y )
 
 #define LInside( a )    \
@@ -66,6 +58,81 @@ static void checked_hide_tooltip( FL_OBJECT *,
 static FL_OBJECT *refocus;
 
 
+/***************************************
+ * Creates an empty form
+ ***************************************/
+
+FL_FORM *
+fli_make_form( FL_Coord w,
+               FL_Coord h )
+{
+    FL_FORM *form;
+
+    form = fl_calloc( 1, sizeof *form );
+
+    /* Convert non-pixel unit into pixles */
+
+    switch ( fli_cntl.coordUnit )
+    {
+        case FL_COORD_PIXEL :
+            break;
+
+        case FL_COORD_MM :
+            w = MMToPixel( w );
+            h = MMToPixel( h );
+            break;
+
+        case FL_COORD_POINT :
+            w = PointToPixel( w );
+            h = PointToPixel( h );
+            break;
+
+        case FL_COORD_centiPOINT :
+            w = CPointToPixel( w );
+            h = CPointToPixel( h );
+            break;
+
+        case FL_COORD_centiMM :
+            w = CMMToPixel( w );
+            h = CMMToPixel( h );
+            break;
+
+        default :
+            M_err( "fli_make_form", "Unknown unit: %d. Reset to pixel",
+                   fli_cntl.coordUnit );
+            fli_cntl.coordUnit = FL_COORD_PIXEL;
+    }
+
+    /* Initialize pointers and non-zero defaults */
+
+    form->w_hr = form->w = w;
+    form->h_hr = form->h = h;
+
+    form->handle_dec_x = 0;
+    form->handle_dec_y = 0;
+
+    form->in_redraw      = 0;
+    form->deactivated    = 1;
+    form->form_callback  = NULL;
+    form->compress_mask  = ExposureMask | ButtonMotionMask | PointerMotionMask;
+    form->key_callback   =
+    form->push_callback  = form->crossing_callback = NULL;
+    form->focusobj       = NULL;
+    form->first          = NULL;
+    form->last           = NULL;
+    form->hotx           = form->hoty = -1;
+    form->use_pixmap     = fli_cntl.doubleBuffer;
+    form->label          = NULL;
+    form->u_vdata        = NULL;
+    form->close_callback = NULL;
+    form->close_data     = NULL;
+    form->icon_pixmap    = form->icon_mask = None;
+    form->no_tooltip     = 0;
+
+    return form;
+}
+
+
 #define IS_BUTTON_CLASS( i )   (    i == FL_BUTTON           \
                                  || i == FL_ROUNDBUTTON      \
                                  || i == FL_ROUND3DBUTTON    \
@@ -75,7 +142,6 @@ static FL_OBJECT *refocus;
                                  || i == FL_PIXMAPBUTTON )
 
 
-
 /***************************************
  * Creates an object, NOT FOR USER.
  ***************************************/
@@ -232,7 +298,7 @@ fl_add_object( FL_FORM   * form,
 
     if ( obj->automatic )
     {
-        form->num_auto_objects++;
+        form->has_auto_objects++;
         fli_recount_auto_objects( );
     }
 
@@ -375,7 +441,7 @@ fli_insert_object( FL_OBJECT * obj,
         fli_insert_composite( obj, before );
 
     if ( ! obj->parent )
-        fli_redraw_form_using_xevent( form, 0, NULL );
+        fl_redraw_form( form );
 }
 
 
@@ -446,7 +512,7 @@ fl_delete_object( FL_OBJECT * obj )
 
     if ( obj->automatic )
     {
-        form->num_auto_objects--;
+        form->has_auto_objects--;
         fli_recount_auto_objects( );
     }
 
@@ -484,8 +550,9 @@ fl_delete_object( FL_OBJECT * obj )
         fli_recalc_intersections( form );
 
     if (    obj->visible
+         && ( ! obj->parent || obj->parent->visible )
          && form && form->visible == FL_VISIBLE )
-        fli_redraw_form_using_xevent( form, 0, NULL );
+        fl_redraw_form( form );
 }
 
 
@@ -606,43 +673,9 @@ fl_free_object( FL_OBJECT * obj )
 
 
 /*-----------------------------------------------------------------------
-   Setting/getting attributes.
+   Setting Attributes.
 -----------------------------------------------------------------------*/
 
-/***************************************
- * Returns the object class of the object
- ***************************************/
-
-int
-fl_get_object_objclass( FL_OBJECT * obj )
-{
-    if ( ! obj )
-    {
-        M_err( "fl_get_object_objclass", "NULL object" );
-        return -1;
-    }
-
-    return obj->objclass;
-}
-
-
-/***************************************
- * Returns the type of the object
- ***************************************/
-
-int
-fl_get_object_type( FL_OBJECT * obj )
-{
-    if ( ! obj )
-    {
-        M_err( "fl_get_object_type", "NULL object" );
-        return -1;
-    }
-
-    return obj->type;
-}
-
-
 /***************************************
  * Sets the boxtype of the object
  ***************************************/
@@ -666,23 +699,6 @@ fl_set_object_boxtype( FL_OBJECT * obj,
 }
 
 
-/***************************************
- * Returns the boxtype of the object
- ***************************************/
-
-int
-fl_get_object_boxtype( FL_OBJECT * obj )
-{
-    if ( ! obj )
-    {
-        M_err( "fl_get_object_boxtype", "NULL object" );
-        return -1;
-    }
-
-    return obj->boxtype;
-}
-
-
 /***************************************
  * Sets the resize property of an object
  ***************************************/
@@ -821,66 +837,6 @@ fl_set_object_color( FL_OBJECT * obj,
 }
 
 
-/***************************************
- * Returns the colors of the object
- ***************************************/
-
-void
-fl_get_object_color( FL_OBJECT * obj,
-                     FL_COLOR  * col1,
-                     FL_COLOR  * col2 )
-{
-    if ( ! obj )
-    {
-        M_err( "fl_get_object_color", "NULL object" );
-        return;
-    }
-
-    if ( col1 )
-        *col1 = obj->col1;
-    if ( col2 )
-        *col2 = obj->col2;
-}
-
-
-/***************************************
- * If called with a non-zero value for 'timeout' the object will
- * receive FL_DBLCLICK events if the mouse is clicked twice within
- * 'timeout' milliseconds, if called with 0 no FL_DBLCLICK events
- * are received.
- ***************************************/
-
-void
-fl_set_object_dblclick( FL_OBJECT     * obj,
-                        unsigned long   timeout )
-{
-    if ( ! obj )
-    {
-        M_err( "fl_set_object_dblclick", "NULL object" );
-        return;
-    }
-
-    obj->click_timeout = timeout;
-}
-
-
-/***************************************
- * Returns the double click timeout for the object
- ***************************************/
-
-unsigned long
-fl_get_object_dblclick( FL_OBJECT * obj )
-{
-    if ( ! obj )
-    {
-        M_err( "fl_get_object_dblclick", "NULL object" );
-        return ULONG_MAX;
-    }
-
-    return obj->click_timeout;
-}
-
-
 /***************************************
  ***************************************/
 
@@ -926,6 +882,23 @@ fl_set_object_dblbuffer( FL_OBJECT * obj,
                                && ( obj )->form->visible == FL_VISIBLE )
 
 
+/***************************************
+ * Returns a pointer to the label of an object
+ ***************************************/
+
+const char *
+fl_get_object_label( FL_OBJECT * obj )
+{
+    if ( ! obj )
+    {
+        M_err( "fl_get_object_label", "NULL object" );
+        return NULL;
+    }
+
+    return obj->label;
+}
+
+
 /***************************************
  * Sets the label of an object
  ***************************************/
@@ -946,38 +919,25 @@ fl_set_object_label( FL_OBJECT  * obj,
     if ( ! strcmp( obj->label, label )  )
         return;
 
-    obj->label = fl_realloc( obj->label, strlen( label ) + 1 );
-    strcpy( obj->label, label );
-
-    if ( ObjIsVisible( obj ) )
+    if ( LInside( obj->align ) )
     {
-        if ( obj->align & FL_ALIGN_INSIDE )
-            fl_redraw_object( obj );
-        else
-        {
-            if ( ! obj->parent )
-                fli_recalc_intersections( obj->form );
-
-            fli_redraw_form_using_xevent( obj->form, 0, NULL );
-        }
+        obj->label = fl_realloc( obj->label, strlen( label ) + 1 );
+        strcpy( obj->label, label );
+        fl_redraw_object( obj );
     }
-}
-
-
-/***************************************
- * Returns the objects label string
- ***************************************/
-
-const char *
-fl_get_object_label( FL_OBJECT * obj )
-{
-    if ( ! obj )
+    else
     {
-        M_err( "fl_get_object_label", "NULL object" );
-        return NULL;
-    }
+        int visible = ObjIsVisible( obj );
 
-    return obj->label;
+        if ( visible )
+            fl_hide_object( obj );
+
+        obj->label = fl_realloc( obj->label, strlen( label ) + 1 );
+        strcpy( obj->label, label );
+
+        if ( visible )
+            fl_show_object( obj );
+    }
 }
 
 
@@ -997,17 +957,18 @@ fl_set_object_lcol( FL_OBJECT * obj,
 
     if ( obj->objclass == FL_BEGIN_GROUP )
     {
-        FL_OBJECT *o = obj->next;;
-
         fl_freeze_form( obj->form );
 
-        for ( ; o && o->objclass != FL_END_GROUP; o = o->next )
+        for ( ; obj && obj->objclass != FL_END_GROUP; obj = obj->next )
         {
-            if ( o->lcol != lcol )
+            if ( obj->lcol != lcol )
             {
-                o->lcol = lcol;
-                fli_handle_object( o, FL_ATTRIB, 0, 0, 0, NULL, 0 );
-                fl_redraw_object( o );
+                obj->lcol = lcol;
+                if ( obj->objclass != FL_BEGIN_GROUP )
+                {
+                    fli_handle_object( obj, FL_ATTRIB, 0, 0, 0, NULL, 0 );
+                    fl_redraw_object( obj );
+                }
             }
         }
 
@@ -1022,23 +983,6 @@ fl_set_object_lcol( FL_OBJECT * obj,
 }
 
 
-/***************************************
- * Returns the label color of an object
- ***************************************/
-
-FL_COLOR
-fl_get_object_lcol( FL_OBJECT * obj )
-{
-    if ( ! obj )
-    {
-        M_err( "fl_get_object_lcol", "NULL object" );
-        return FL_NOCOLOR;
-    }
-
-    return obj->lcol;
-}
-
-
 /***************************************
  * Sets the label size of an object
  ***************************************/
@@ -1080,9 +1024,6 @@ fl_set_object_lsize( FL_OBJECT * obj,
             obj->lsize = lsize;
             fli_handle_object( obj, FL_ATTRIB, 0, 0, 0, NULL, 0 );
 
-            if ( ! obj->parent )
-                fli_recalc_intersections( obj->form );
-
             if ( visible )
                 fl_show_object( obj );
         }
@@ -1090,23 +1031,6 @@ fl_set_object_lsize( FL_OBJECT * obj,
 }
 
 
-/***************************************
- * Returns the label size of an object
- ***************************************/
-
-int
-fl_get_object_lsize( FL_OBJECT * obj )
-{
-    if ( ! obj )
-    {
-        M_err( "fl_get_object_lsize", "NULL object" );
-        return -1;
-    }
-
-    return obj->lsize;
-}
-
-
 /***************************************
  * Sets the label style of an object
  ***************************************/
@@ -1153,23 +1077,6 @@ fl_set_object_lstyle( FL_OBJECT * obj,
 }
 
 
-/***************************************
- * Returns the label style of an object
- ***************************************/
-
-int
-fl_get_object_lstyle( FL_OBJECT * obj )
-{
-    if ( ! obj )
-    {
-        M_err( "fl_get_object_lstyle", "NULL object" );
-        return -1;
-    }
-
-    return obj->lstyle;
-}
-
-
 /***************************************
  * Sets the label alignment of an object
  ***************************************/
@@ -1213,23 +1120,6 @@ fl_set_object_lalign( FL_OBJECT * obj,
 }
 
 
-/***************************************
- * Returns the label alignment of an object
- ***************************************/
-
-int
-fl_get_object_lalign( FL_OBJECT * obj )
-{
-    if ( ! obj )
-    {
-        M_err( "fl_get_object_lalign", "NULL object" );
-        return -1;
-    }
-
-    return obj->align;
-}
-
-
 /***************************************
  * Makes an object active
  ***************************************/
@@ -1241,10 +1131,8 @@ activate_object( FL_OBJECT * obj )
         return;
 
     obj->active = 1;
-
     if ( obj->input && obj->active && ! obj->form->focusobj )
         fl_set_focus_object( obj->form, obj );
-
     if ( obj->child )
         fli_activate_composite( obj );
 }
@@ -1264,14 +1152,8 @@ fl_activate_object( FL_OBJECT * obj )
     }
 
     if ( obj->objclass == FL_BEGIN_GROUP )
-    {
-        obj->active = 1;
-
-        for ( obj = obj->next;
-              obj && obj->objclass != FL_END_GROUP;
-              obj = obj->next )
+        for ( ; obj && obj->objclass != FL_END_GROUP; obj = obj->next )
             activate_object( obj );
-    }
     else
         activate_object( obj );
 }
@@ -1309,36 +1191,13 @@ fl_deactivate_object( FL_OBJECT * obj )
     }
 
     if ( obj->objclass == FL_BEGIN_GROUP )
-    {
-        obj->active = 0;
-
-        for ( obj = obj->next;
-              obj && obj->objclass != FL_END_GROUP;
-              obj = obj->next )
+        for ( ; obj && obj->objclass != FL_END_GROUP; obj = obj->next )
             deactivate_object( obj );
-    }
     else
         deactivate_object( obj );
 }
 
 
-/***************************************
- * Returns if an object is in active state, i.e. reacting to events
- ***************************************/
-
-int
-fl_object_is_active( FL_OBJECT * obj )
-{
-    if ( ! obj )
-    {
-        M_err( "fl_object_is_active", "NULL object" );
-        return 0;
-    }
-
-    return obj->active;
-}
-
-
 /***************************************
  * Makes an object visible and sets the visible flag to 1
  ***************************************/
@@ -1352,10 +1211,7 @@ fli_show_object( FL_OBJECT * obj )
     obj->visible = 1;
 
     if ( obj->child )
-    {
         fli_show_composite( obj );
-        fli_handle_object( obj, FL_ATTRIB, 0, 0, 0, NULL, 0 );
-    }
 
     if ( obj->input && obj->active && ! obj->form->focusobj )
         fl_set_focus_object( obj->form, obj );
@@ -1369,7 +1225,7 @@ fli_show_object( FL_OBJECT * obj )
 void
 fl_show_object( FL_OBJECT * obj )
 {
-    FL_OBJECT *o = obj->next;
+    FL_OBJECT *o = obj;
 
     if ( ! obj )
     {
@@ -1377,31 +1233,13 @@ fl_show_object( FL_OBJECT * obj )
         return;
     }
 
-     if ( obj->objclass == FL_BEGIN_GROUP )
-        for ( ; o && o->objclass != FL_END_GROUP; o = o->next )
-            fli_show_object( o );
+    if ( obj->objclass == FL_BEGIN_GROUP )
+        for ( ; obj && obj->objclass != FL_END_GROUP; obj = obj->next )
+            fli_show_object( obj );
     else
         fli_show_object( obj );
 
-     fli_redraw_form_using_xevent( obj->form, 0, NULL );
-}
-
-
-/***************************************
- * Returns if an object is shown (gien that the form it
- * belongs to is visible!)
- ***************************************/
-
-int
-fl_object_is_visible( FL_OBJECT * obj )
-{
-    if ( ! obj )
-    {
-        M_err( "fl_object_is_visible", "NULL object" );
-        return 0;
-    }
-
-    return obj->visible;
+    fl_redraw_object( o );
 }
 
 
@@ -1438,10 +1276,10 @@ fli_hide_and_get_region( FL_OBJECT * obj,
     if ( obj->objclass == FL_CANVAS || obj->objclass == FL_GLCANVAS )
     {
         fl_hide_canvas( obj );
-        extra        = 3;
-        xrect.x      = obj->x - extra;
-        xrect.y      = obj->y - extra;
-        xrect.width  = obj->w + 2 * extra + 1;
+        extra = 3;
+        xrect.x = obj->x - extra;
+        xrect.y = obj->y - extra;
+        xrect.width = obj->w + 2 * extra + 1;
         xrect.height = obj->h + 2 * extra + 1;
     }
     else
@@ -1450,9 +1288,9 @@ fli_hide_and_get_region( FL_OBJECT * obj,
     
         if ( obj->objclass == FL_FRAME )
         {
-            extra         = FL_abs( obj->bw );
-            xrect.x      -= extra;
-            xrect.y      -= extra;
+            extra = FL_abs( obj->bw );
+            xrect.x -= extra;
+            xrect.y -= extra;
             xrect.width  += 2 * extra + 1;
             xrect.height += 2 * extra + 1;
         }
@@ -1471,8 +1309,7 @@ fli_hide_and_get_region( FL_OBJECT * obj,
  * Makes an object (and all its children) invisible
  ***************************************/
 
-void
-fl_hide_object( FL_OBJECT * obj )
+void fl_hide_object( FL_OBJECT * obj )
 {
     FL_OBJECT *tmp;
     FL_RECT xrect;
@@ -1501,20 +1338,14 @@ fl_hide_object( FL_OBJECT * obj )
               tmp = tmp->next )
         {
             if ( tmp->child )
-            {
                 fli_hide_composite( tmp, &reg );
-                fli_handle_object( tmp, FL_ATTRIB, 0, 0, 0, NULL, 0 );
-            }
 
             fli_hide_and_get_region( tmp, &reg );
         }
     else
     {
         if ( obj->child )
-        {
             fli_hide_composite( obj, &reg );
-            fli_handle_object( obj, FL_ATTRIB, 0, 0, 0, NULL, 0 );
-        }
 
         fli_hide_and_get_region( obj, &reg );
     }
@@ -1537,7 +1368,7 @@ fl_hide_object( FL_OBJECT * obj )
     fl_set_clipping( xrect.x, xrect.y, xrect.width, xrect.height );
     fl_set_text_clipping( xrect.x, xrect.y, xrect.width, xrect.height );
 
-    fli_redraw_form_using_xevent( obj->form, 0, NULL );
+    fl_redraw_form( obj->form );
 
     fli_unset_perm_clipping( );
     fl_unset_clipping( );
@@ -1637,13 +1468,10 @@ fli_convert_shortcut( const char * str,
                 break;
 
             default :
-                if ( offset & ( FL_CONTROL_MASK | FL_ALT_MASK ) )
-                {
-                    sc[ i ] = toupper( ( int ) *c );
-                    if ( offset & FL_CONTROL_MASK )
-                        sc[ i ] -= 'A' - 1;
-                    sc[ i++ ] += offset & ~ FL_CONTROL_MASK;
-                }
+                if (    offset & ( FL_CONTROL_MASK | FL_ALT_MASK )
+                        && (    ( *c >= 'A' && *c <= 'Z' )
+                             || ( *c >= 'a' && *c <= 'z' ) ) )
+                    sc[ i++ ] = toupper( ( int ) *c ) - 'A' + 1;
                 else
                     sc[ i++ ] = *c + offset;
                 offset = 0;
@@ -1822,7 +1650,7 @@ fl_get_focus_object( FL_FORM * form )
 -----------------------------------------------------------------------*/
 
 /***************************************
- * Returns an object of type 'find' in a form, starting at 'obj'.
+ * Returns an object of type 'find' in a form , starting at 'obj'.
  * If find_object() does not return an object the event that
  * triggered the call will be eaten. This is how the deactived
  * and inactive objects reject events.
@@ -1840,6 +1668,7 @@ fli_find_object( FL_OBJECT * obj,
         if (    obj->objclass != FL_BEGIN_GROUP
              && obj->objclass != FL_END_GROUP
              && obj->visible
+             && ( ! obj->parent || obj->parent->visible )
              && (     obj->active
                   || ( obj->posthandle && ! obj->active )
                   || ( obj->tooltip && *obj->tooltip && ! obj->active ) ) )
@@ -1885,6 +1714,7 @@ fli_find_object_backwards( FL_OBJECT * obj,
         if (    obj->objclass != FL_BEGIN_GROUP
              && obj->objclass != FL_END_GROUP
              && obj->visible
+             && ( ! obj->parent || obj->parent->visible )
              && (     obj->active
                   || ( obj->posthandle && ! obj->active )
                   || ( obj->tooltip && *obj->tooltip && ! obj->active ) ) )
@@ -1982,38 +1812,11 @@ object_is_clipped( FL_OBJECT * obj )
 
 
 /***************************************
- * Marks an object for redraw
- ***************************************/
-
-static void
-mark_object_for_redraw( FL_OBJECT * obj )
-{
-    if ( ! obj )
-    {
-        M_err( "mark_object_for_redraw", "Redrawing NULL object" );
-        return;
-    }
-
-    if  (    ! obj->form
-          || ! obj->visible
-          || ( obj->parent && ! obj->parent->visible )
-          || obj->objclass == FL_BEGIN_GROUP
-          || obj->objclass == FL_END_GROUP )
-        return;
-
-    obj->redraw = 1;
-
-    for ( obj = obj->child; obj; obj = obj->nc )
-        mark_object_for_redraw( obj );
-}
-
-
-/***************************************
- * Redraws all marked objects and removes the mark. It is important NOT to
- * set any clip masks inside this function (except for free objects) since
- * that would prevent the drawing function from drawing labels. That would
- * be wrong since fl_redraw_object() calls redraw_marked() directly. All
- * cliping must done prior to calling this routines
+ * Redraws all marked objects and reduces the mark. It is important
+ * NOT to set any clip masks inside this function (except for free objects)
+ * since that would prevent the drawing function from drawing labels. That
+ * would be wrong since fl_redraw_object() calls redraw_marked()
+ * directly. All cliping must done prior to calling this routines
  ***************************************/
 
 static void
@@ -2027,20 +1830,27 @@ redraw_marked( FL_FORM * form,
 
     /* Beside the case that the form isn't visible or frozen we also need
        to consider the case that a redraw for an object is initiated while
-       another (parent) object gets redrawn (an example would be a scrollbar
+       an other (parent) object gets redrawn (an example would be a scrollbar
        that during its redraw calls a function for setting the value of its
        slider which in turn triggers the redraw of the slider). In that case
        the (child) object is not to be redrawn yet (it's already marked for
-       redraw and will be redrawn later automatically since child object always
+       redraw and will be redrawn later automaticallysince child object always
        come after their parent objects) because that would mess up the behind-
        the-scenes-switching of the window/pixmaps that drawing is done in. */
 
-    if ( form->visible != FL_VISIBLE || form->frozen )
+    if ( form->visible != FL_VISIBLE || form->frozen > 0 || form->in_redraw )
         return;
 
+    form->in_redraw = 1;
+
+    /* Set the window (or drawable) to be drawn to (flx->win) */
+
+    fli_set_form_window( form );
+    fli_create_form_pixmap( form );
+
     /* Check if there are any objects that partially or fully hide one of
        the objects to be redrawn and mark those also for redrawing (and, of
-       course, also those that are "above" these newly added objects etc.) */
+       course, also those that are "above" this newly added object etc.) */
 
     for ( obj = form->first; obj; obj = obj->next )
         if (    obj->visible
@@ -2070,15 +1880,15 @@ redraw_marked( FL_FORM * form,
                     continue;
                  
                 if ( objects_intersect( obj, o ) )
-                    mark_object_for_redraw( o );
+                {
+                    o->redraw = 1;
+                    if ( o->child )
+                        fli_mark_composite_for_redraw( o );
+                }
             }
         }
     }
 
-    /* Set the window (or drawable) to be drawn to (flx->win) */
-
-    fli_set_form_window( form );
-
     /* Now redraw all marked objects */
 
     for ( obj = form->first; obj; obj = obj->next )
@@ -2089,12 +1899,13 @@ redraw_marked( FL_FORM * form,
         obj->redraw = 0;
 
         if (    ! obj->visible
+             || ( obj->parent && ! obj->parent->visible )
              || ( fli_perm_clip && object_is_clipped( obj ) ) )
             continue;
 
         fli_create_object_pixmap( obj );
 
-        /* Don't allow free objects to draw outside of their boxes. Check
+        /* Will not allow free object draw outside of its box. Check
            perm_clip so we don't have draw regions we don't have to
            (Expose etc.) */
 
@@ -2116,6 +1927,10 @@ redraw_marked( FL_FORM * form,
 
         fli_handle_object( obj, FL_DRAWLABEL, 0, 0, 0, NULL, 0 );
     }
+
+    fli_show_form_pixmap( form );
+
+    form->in_redraw = 0;
 }
 
 
@@ -2132,7 +1947,7 @@ fl_redraw_object( FL_OBJECT * obj )
         return;
     }
 
-    if ( ! obj->form || ! obj->visible )
+    if ( ! obj->form )
         return;
 
     if ( obj->objclass == FL_BEGIN_GROUP )
@@ -2140,12 +1955,22 @@ fl_redraw_object( FL_OBJECT * obj )
         FL_OBJECT *o = obj->next;
 
         for ( ; o && o->objclass != FL_END_GROUP; o = o->next )
-            mark_object_for_redraw( o );
+            o->redraw = 1;
     }
     else
-        mark_object_for_redraw( obj );
+        obj->redraw = 1;
 
-    redraw_marked( obj->form, 0, NULL );
+    /* For composite objects also flag all children */
+
+    if (    obj->child
+         && ( ! obj->parent || obj->parent->visible )
+         && obj->visible )
+        fli_mark_composite_for_redraw( obj );
+
+    /* If object is a child object and the parent is not visible, do nothing */
+
+    if ( obj->visible && ( ! obj->parent || obj->parent->visible ) )
+        redraw_marked( obj->form, 0, NULL );
 }
 
 
@@ -2170,7 +1995,7 @@ objects_intersect( FL_OBJECT * obj1,
         if (    ob[ i ]->objclass == FL_CANVAS
              || ob[ i ]->objclass == FL_GLCANVAS )
         {
-            extra        = 3;
+            extra = 3;
             xrect.x      = ob[ i ]->x - extra;
             xrect.y      = ob[ i ]->y - extra;
             xrect.width  = ob[ i ]->w + 2 * extra + 1;
@@ -2182,7 +2007,7 @@ objects_intersect( FL_OBJECT * obj1,
     
             if ( ob[ i ]->objclass == FL_FRAME )
             {
-                extra         = FL_abs( ob[ i ]->bw );
+                extra = FL_abs( ob[ i ]->bw );
                 xrect.x      -= extra;
                 xrect.y      -= extra;
                 xrect.width  += 2 * extra + 1;
@@ -2232,7 +2057,46 @@ object_is_under( FL_OBJECT * obj )
 
 
 /***************************************
- * Redraws a form
+ * Marks all objects for redraw
+ ***************************************/
+
+static void
+mark_for_redraw( FL_FORM * form )
+{
+    FL_OBJECT *obj;
+
+    if ( ! form )
+    {
+        M_err( "mark_for_redraw", "Drawing NULL form" );
+        return;
+    }
+
+    for ( obj = form->first; obj; obj = obj->next )
+    {
+        if (    ! obj->visible
+             || obj->objclass == FL_BEGIN_GROUP
+             || obj->objclass == FL_END_GROUP )
+            continue;
+
+        obj->redraw = 1;
+    }
+}
+
+
+/***************************************
+ * Draws a form
+ ***************************************/
+
+void
+fl_redraw_form( FL_FORM * form )
+{
+    mark_for_redraw( form );
+    redraw_marked( form, 0, NULL );
+}
+
+
+/***************************************
+ * Draws a form
  ***************************************/
 
 void
@@ -2240,65 +2104,11 @@ fli_redraw_form_using_xevent( FL_FORM * form,
                               int       key,
                               XEvent  * xev )
 {
-    FL_OBJECT *obj;
-
-    if ( ! form || form->visible != FL_VISIBLE || form->frozen > 0 )
-        return;
-
-    /* Set the window (or drawable) to be drawn to (flx->win) */
-
-    fli_set_form_window( form );
-    fli_create_form_pixmap( form );
-
-    for ( obj = form->first; obj; obj = obj->next )
-    {
-        obj->redraw = 0;
-
-        if (    ! obj->visible
-             || ( fli_perm_clip && object_is_clipped( obj ) ) )
-            continue;
-
-        fli_create_object_pixmap( obj );
-
-        /* Don't allow free objects to draw outside of their boxes. Check
-           perm_clip so we don't have draw regions we don't have to
-           (Expose etc.) */
-
-        if ( ( obj->objclass == FL_FREE || obj->clip ) && ! fli_perm_clip )
-        {
-            fl_set_clipping( obj->x, obj->y, obj->w, obj->h );
-            fl_set_text_clipping( obj->x, obj->y, obj->w, obj->h );
-        }
-
-        fli_handle_object( obj, FL_DRAW, 0, 0, key, xev, 0 );
-
-        if ( ( obj->objclass == FL_FREE || obj->clip ) && ! fli_perm_clip )
-        {
-            fl_unset_clipping( );
-            fl_unset_text_clipping( );
-        }
-
-        fli_show_object_pixmap( obj );
-
-        fli_handle_object( obj, FL_DRAWLABEL, 0, 0, 0, NULL, 0 );
-    }
-
-    fli_show_form_pixmap( form );
+    mark_for_redraw( form );
+    redraw_marked( form, key, xev );
 }
 
 
-/***************************************
- * Exported function for drawing a form
- ***************************************/
-
-void
-fl_redraw_form( FL_FORM * form )
-{
-    fli_redraw_form_using_xevent( form, 0, NULL );
-}
-
-
-
 /***************************************
  * Disables drawing of form
  ***************************************/
@@ -2335,10 +2145,11 @@ fl_unfreeze_form( FL_FORM * form )
         return;
     }
 
-    if ( --form->frozen == 0 && form->visible == FL_VISIBLE )
-        fli_redraw_form_using_xevent( form, 0, NULL );
-}
+    form->frozen--;
 
+    if ( form->frozen == 0 && form->visible == FL_VISIBLE )
+        redraw_marked( form, 0, NULL );
+}
 
 /*-----------------------------------------------------------------------
    Handling Routines.
@@ -2477,7 +2288,7 @@ handle_object( FL_OBJECT * obj,
 #endif
 
     if ( obj->objclass == FL_BEGIN_GROUP || obj->objclass == FL_END_GROUP )
-        return FL_RETURN_NONE;
+        return 0;
 
     if ( ! obj->handle )
         return FL_RETURN_NONE;
@@ -2591,8 +2402,7 @@ handle_object( FL_OBJECT * obj,
 
  recover:
 
-    /* Call a pre-handler if it exists and return if it tells us the event
-       has been handled completely */
+    /* Call a pre-handler if it exists */
 
     if (    obj->prehandle
          && event != FL_FREEMEM
@@ -2631,7 +2441,7 @@ handle_object( FL_OBJECT * obj,
     }
 
     return ( event == FL_DBLCLICK || event == FL_TRPLCLICK ) ?
-           ( int ) FL_RETURN_NONE : obj->returned;
+           FL_RETURN_NONE : obj->returned;
 }
 
 
@@ -2671,7 +2481,7 @@ fli_handle_object( FL_OBJECT * obj,
 
 
 /***************************************
- * Sets the callback routine for the object
+ * Sets the call_back routine for the object
  ***************************************/
 
 FL_CALLBACKPTR
@@ -2958,7 +2768,6 @@ fl_set_object_posthandler( FL_OBJECT    * obj,
                            FL_HANDLEPTR   post )
 {
     FL_HANDLEPTR oldh = obj->posthandle;
-
     obj->posthandle = post;
     return oldh;
 }
@@ -3327,22 +3136,23 @@ fl_get_object_bbox( FL_OBJECT * obj,
 
     if ( obj->label && *obj->label )
     {
+        int len = strlen( obj->label );
         int sw,
             sh;
         int xx,
             yy,
-            ascent,
-            descent;
+            a,
+            d;
 
-        fl_get_string_dimension( obj->lstyle, obj->lsize, obj->label,
-                                 strlen( obj->label ), &sw, &sh );
-        fl_get_char_height( obj->lstyle, obj->lsize, &ascent, &descent );
+        fl_get_string_dimension( obj->lstyle, obj->lsize, obj->label, len,
+                                 &sw, &sh );
+        fl_get_char_height( obj->lstyle, obj->lsize, &a, &d );
         fl_get_align_xy( obj->align, obj->x, obj->y, obj->w, obj->h,
-                         sw, sh + descent, 3, 3, &xx, &yy );
+                         sw, sh + d, 3, 3, &xx, &yy );
         lrect.x      = xx - 1;
         lrect.y      = yy;
         lrect.width  = sw + 1;
-        lrect.height = sh + descent;
+        lrect.height = sh + d;
     }
 
     xr = get_bounding_rect( &lrect, &orect );
@@ -3379,9 +3189,9 @@ get_object_bbox_rect( FL_OBJECT * obj,
 
     fl_get_object_bbox( obj, &x, &y, &w, &h );
 
-    xr->x      = x;
-    xr->y      = y;
-    xr->width  = w;
+    xr->x = x;
+    xr->y = y;
+    xr->width = w;
     xr->height = h;
 }
 
@@ -3400,9 +3210,9 @@ fl_set_object_automatic( FL_OBJECT * obj,
         if ( obj->form )
         {
             if ( flag )
-                obj->form->num_auto_objects++;
+                obj->form->has_auto_objects++;
             else
-                obj->form->num_auto_objects--;
+                obj->form->has_auto_objects--;
         }
 
         fli_recount_auto_objects( );
@@ -3410,22 +3220,6 @@ fl_set_object_automatic( FL_OBJECT * obj,
 }
 
 
-/***************************************
- ***************************************/
-
-int
-fl_object_is_automatic( FL_OBJECT * obj )
-{
-    if ( ! obj )
-    {
-        M_err( "fl_object_is_automatic", "NULL object" );
-        return 0;
-    }
-
-    return obj->automatic;
-}
-
-
 /***************************************
  ***************************************/
 
@@ -3512,8 +3306,8 @@ fl_set_object_helper( FL_OBJECT  * obj,
  ***************************************/
 
 int
-fl_set_object_return( FL_OBJECT    * obj,
-                      unsigned int   when )
+fl_set_object_return( FL_OBJECT * obj,
+                      int         when )
 {
     int old_when;
 
@@ -3554,24 +3348,6 @@ fl_notify_object( FL_OBJECT * obj,
 }
 
 
-/***************************************
- * Sets the visibility flag for an object and all its children
- * without inducing a redraw. Used e.g. in browser and multi-
- * line input object's code to switch scrollbars on and off.
- ***************************************/
-
-void
-fli_set_object_visibility( FL_OBJECT * obj,
-                           int         vis )
-{
-    if ( obj )        /* let's be careful... */
-    {
-        obj->visible = vis;
-        for ( obj = obj->child; obj; obj = obj->nc )
-            fli_set_object_visibility( obj, vis );
-    }
-}
-
 
 /*
  * Local variables:
