@@ -330,7 +330,7 @@ fl_delete_select_item( FL_OBJECT      * obj,
 
     if ( fli_check_popup_entry_exists( item ) != 0 )
     {
-        M_err( "fl_delete_select_item", "Item doesn't exist" );
+        M_err( "fl_delete_select_item", "Item doesnt exist" );
         return -1;
     }
 
@@ -350,8 +350,7 @@ fl_delete_select_item( FL_OBJECT      * obj,
     
 
 /***************************************
- * (Re)populate a select object's popup via an
- * array of FL_POPUP_ITEM structures
+ * (Re)polulate a select objects popup via an array of FL_POPUP_ITEM structures
  ***************************************/
 
 long
@@ -370,18 +369,16 @@ fl_set_select_items( FL_OBJECT     * obj,
 
     sp = obj->spec;
 
-    /* If no popup exists yet create it, otherwise remove all entries */
-
     if ( sp->popup == NULL )
         sp->popup = fli_popup_add( FL_ObjWin( obj ), NULL,
                                    "fl_set_select_items" );
-    else
-    {
-        while ( sp->popup->entries != NULL )
-            fl_popup_entry_delete( sp->popup->entries );
 
-        fli_popup_reset_counter( sp->popup );
-    }
+    /* Remove all existing entries and reset the popups internal counter */
+
+    while ( sp->popup->entries != NULL )
+        fl_popup_entry_delete( sp->popup->entries );
+
+    fli_popup_reset_counter( sp->popup );
 
     /* Now add the new ones */
 
@@ -533,7 +530,6 @@ fl_set_select_item( FL_OBJECT      * obj,
 {
     FL_POPUP_ENTRY *e;
     FLI_SELECT_SPEC *sp;
-    FL_POPUP_RETURN *r;
 
     if ( obj == NULL )
     {
@@ -569,9 +565,7 @@ fl_set_select_item( FL_OBJECT      * obj,
         return NULL;
     }
 
-    r = fli_set_popup_return( entry );
-    fl_redraw_object( obj );
-    return r;
+    return fli_set_popup_return( entry );
 }
 
 
