@@ -54,7 +54,7 @@ static GC create_gc( FL_OBJECT *,
 
 
 /***************************************
- * Creates a new textbox object
+ * Creates a new textbox
  ***************************************/
 
 FL_OBJECT *
@@ -95,6 +95,7 @@ fli_create_tbox( int          type,
                         fli_cntl.browserFontSize : FLI_TBOX_FONTSIZE;
     sp->def_style     = FL_NORMAL_STYLE;
     sp->def_align     = FL_ALIGN_LEFT;
+    sp->def_lcol      = obj->lcol;
     sp->defaultGC     = None;
     sp->backgroundGC  = None;
     sp->selectGC      = None;
@@ -968,7 +969,6 @@ fli_tbox_set_fontstyle( FL_OBJECT * obj,
 
 
 /***************************************
- * Sets the x-offset in pixels of the text displayed in the textbox
  ***************************************/
 
 int
@@ -992,9 +992,6 @@ fli_tbox_set_xoffset( FL_OBJECT * obj,
 
 
 /***************************************
- * Sets the x-offset of the text displayed in the textbox as a
- * number between 0 (starts of lines are shown) and 1 (end of
- * longest line is shown)
  ***************************************/
 
 double
@@ -1018,7 +1015,6 @@ fli_tbox_set_rel_xoffset( FL_OBJECT * obj,
     
 
 /***************************************
- * Sets the y-offset in pixels of the text displayed in the textbox
  ***************************************/
 
 int
@@ -1042,9 +1038,6 @@ fli_tbox_set_yoffset( FL_OBJECT * obj,
 
 
 /***************************************
- * Sets the y-offset of the text displayed in the textbox as a
- * number between 0 (show start of text) and 1 (show end of
- * text)
  ***************************************/
 
 double
@@ -1068,7 +1061,6 @@ fli_tbox_set_rel_yoffset( FL_OBJECT * obj,
 
 
 /***************************************
- * Returns the x-offset in pixels of the text displayed in the textbox
  ***************************************/
 
 int
@@ -1079,9 +1071,6 @@ fli_tbox_get_xoffset( FL_OBJECT * obj )
 
 
 /***************************************
- * Returns the x-offset of the text displayed in the textbox
- * as a number between 0 (starts of lines are shown) and 1
- * (end of longest line s shown)
  ***************************************/
 
 double
@@ -1097,7 +1086,6 @@ fli_tbox_get_rel_xoffset( FL_OBJECT * obj )
 
 
 /***************************************
- * Returns the y-offset in pixels of the text displayed in the textbox
  ***************************************/
 
 int
@@ -1107,11 +1095,8 @@ fli_tbox_get_yoffset( FL_OBJECT * obj )
 }
 
 
-/*************************************** 
- * Returns the y-offset of the text displayed in the textbox
- * as a number between 0 (start of text is shown) and 1 (end
- * of text is shown)
-***************************************/
+/***************************************
+ ***************************************/
 
 double
 fli_tbox_get_rel_yoffset( FL_OBJECT * obj )
@@ -1126,8 +1111,6 @@ fli_tbox_get_rel_yoffset( FL_OBJECT * obj )
 
 
 /***************************************
- * Returns the y-offset (in pixel) for a line (or -1 if the line
- * does not exist).
  ***************************************/
 
 int
@@ -1153,9 +1136,6 @@ fli_tbox_set_topline( FL_OBJECT * obj,
 {
     FLI_TBOX_SPEC *sp = obj->spec;
 
-    if ( ! sp->num_lines )
-        return;
-
     if ( line < 0 )
         line = 0;
     else if ( line >= sp->num_lines )
@@ -1175,9 +1155,6 @@ fli_tbox_set_bottomline( FL_OBJECT * obj,
 {
     FLI_TBOX_SPEC *sp = obj->spec;
 
-    if ( ! sp->num_lines )
-        return;
-
     if ( line < 0 )
         line = 0;
     else if ( line >= sp->num_lines )
@@ -1198,9 +1175,6 @@ fli_tbox_set_centerline( FL_OBJECT * obj,
 {
     FLI_TBOX_SPEC *sp = obj->spec;
 
-    if ( ! sp->num_lines )
-        return;
-
     if ( line < 0 )
         line = 0;
     else if ( line >= sp->num_lines )
@@ -1399,7 +1373,6 @@ fli_tbox_set_dblclick_callback( FL_OBJECT      * obj,
     
 
 /***************************************
- * Creates a GC with the required settings
  ***************************************/
 
 static GC
@@ -1510,7 +1483,7 @@ fli_tbox_prepare_drawing( FL_OBJECT * obj )
     if ( sp->defaultGC )
         XFreeGC( flx->display, sp->defaultGC );
 
-    sp->defaultGC = create_gc( obj, sp->def_style, sp->def_size, obj->lcol,
+    sp->defaultGC = create_gc( obj, sp->def_style, sp->def_size, sp->def_lcol,
                                sp->x, sp->y, sp->w, sp->h );
 
     /* Create background GC for redraw deselected lines */
@@ -1986,7 +1959,7 @@ fli_handle_mouse_wheel( int       * ev,
 
     if ( *ev == FL_RELEASE )
     {
-        *ev = FL_KEYPRESS;
+        *ev = FL_KEYBOARD;
 
         if ( xev && shiftkey_down( ( ( XButtonEvent * ) xev )->state ) )
         {
@@ -2045,9 +2018,6 @@ find_mouse_line( FL_OBJECT * obj,
 
 
 /***************************************
- * Sets if the textbox reacts to keys that change the vertical
- * position (used by browser when vertical scrollbar is switched
- * on or off)
  ***************************************/
 
 void
@@ -2059,9 +2029,6 @@ fli_tbox_react_to_vert( FL_OBJECT * obj,
 
 
 /***************************************
- * Sets if the textbox reacts to keys that change the horizontal
- * position (used by browser when horizontal scrollbar is switched
- * on or off)
  ***************************************/
 
 void
@@ -2073,7 +2040,7 @@ fli_tbox_react_to_hori( FL_OBJECT * obj,
 
 
 /***************************************
- * Handles a mouse event, returns whether a selection change has occured
+ * Handles a mouse change, returns whether a selection change has occured
  ***************************************/
 
 #define DESELECT 0
@@ -2244,7 +2211,7 @@ handle_mouse( FL_OBJECT * obj,
 
 
 /***************************************
- * Called for events concerning the textbox
+ * Handles the textbox
  ***************************************/
 
 static int
@@ -2291,7 +2258,7 @@ handle_tbox( FL_OBJECT * obj,
                 sp->callback( obj, sp->callback_data );
             break;
 
-        case FL_KEYPRESS :
+        case FL_KEYBOARD :
             ret = handle_keyboard( obj, key );
             break;
 
