@@ -240,14 +240,14 @@ fl_winmaxsize( Window   win,
  ***************************************/
 
 void
-fl_winstepsize( Window   win,
+fl_winstepunit( Window   win,
                 FL_Coord dx,
                 FL_Coord dy )
 {
     XSizeHints mxsh,
                *sh;
 
-    /* Copy current constraints */
+    /* copy current constraints */
 
     mxsh            = st_xsh;
     mxsh.flags      = 0;
@@ -524,7 +524,7 @@ setup_catch_destroy( Window win )
 
 
 /***************************************
- * Waits until we know for sure the newly mapped window is visible
+ * Wait until we know for sure the newly mapped window is visible
  ***************************************/
 
 static void
@@ -760,7 +760,7 @@ fl_winshow( Window win )
 {
     XMapRaised( flx->display, win );
 
-    /* Wait until the newly mapped window shows up */
+    /* wait until the newly mapped win shows up */
 
     if ( st_xwmh.initial_state == NormalState )
         wait_mapwin( win );
@@ -1021,7 +1021,7 @@ fl_winicontitle( Window       win,
 
 
 /***************************************
- * Grab keyboard focus
+ * grab keyboard focus
  ***************************************/
 
 void
