@@ -284,12 +284,12 @@ fli_xyplot_interpolate( FL_OBJECT * ob,
 
     newn = 1.01 + ( x[ n2 - 1 ] - x[ n1 ] ) / sp->grid[ id ];
 
-    /* Test if number of points exceeds screen resolution by a large margin */
+    /* Far exceeds screen resolution. warn */
 
     if ( newn > 5000 )
     {
         M_err( "fli_xyplot_interpolate",
-               "interpolating %d points, exceeds screen res", newn );
+               "interpolating %d points. Far exceeds screen res", newn );
         return -1;
     }
 
@@ -330,7 +330,7 @@ fli_xyplot_interpolate( FL_OBJECT * ob,
 }
 
 
-/* To avoid singularity or extreme scaling factors */
+/* to avoid singularity or extreme scaling factors */
 
 #define FMIN  1.0e-25
 
@@ -421,17 +421,21 @@ fli_xyplot_compute_data_bounds( FL_OBJECT * ob,
     }
 
     for ( *n1 = -1, i = 0; i < sp->n[ id ] && *n1 < 0; i++ )
+    {
         if ( x[ i ] >= xmin )
             *n1 = i;
+    }
 
     if ( *n1 > 0 )
         *n1 -= 1;
-    else if ( *n1 < 0 )
+    if ( *n1 < 0 )
         *n1 = 0;
 
     for ( *n2 = -1, i = sp->n[ id ]; --i >= 0 && *n2 < 0; )
+    {
         if ( x[ i ] <= xmax )
             *n2 = i;
+    }
 
     if ( *n2 < 0 )
         *n2 = sp->n[ id ] > 1 ? sp->n[ id ] : 1;
@@ -493,7 +497,7 @@ draw_curve_only( FL_OBJECT * ob )
         drawsymbol = 0;
         noline = 0;
 
-        /* Without autoscaling some of the data might fall outside the range
+        /* If non-autoscaling, some of the data might fall outside the range
            desired, get rid of them so actual data that get plotted are bound
            by (n1, n2) */
 
@@ -1281,7 +1285,7 @@ convert_coord( FL_OBJECT       * ob,
                                      strlen( label ) );
         }
 
-        /* How much space to leave for ytics ylabels */
+        /* how much space to leave for ytics ylabels */
 
         extrax1 += ticl + 1;
         extrax1 += w;
@@ -1320,18 +1324,18 @@ convert_coord( FL_OBJECT       * ob,
                                         strlen( sp->ymargin2 ) );
     }
 
-    sp->xi = sp->objx + extrax1;
-    sp->yi = sp->objy + extray1;
-    sp->xf = sp->objx + ob->w - extrax2;
-    sp->yf = sp->objy + ob->h - extray2;
+    sp->xi = ob->x + extrax1;
+    sp->yi = ob->y + extray1;
+    sp->xf = ob->x + ob->w - extrax2;
+    sp->yf = ob->y + ob->h - extray2;
 
     sp->ax  = ( sp->xf - sp->xi ) / ( sp->xscmax - sp->xscmin );
     sp->bx  = sp->xi - sp->ax * sp->xscmin;
-    sp->bxm = sp->bx;
+    sp->bxm = sp->bx - ob->x + sp->objx;
 
     sp->ay  = ( sp->yf - sp->yi ) / ( sp->yscmin - sp->yscmax );
     sp->by  = sp->yi - sp->ay * sp->yscmax;
-    sp->bym = sp->by;
+    sp->bym = sp->by - ob->y + sp->objy;
 
     fl_xyplot_gen_xtic( ob );
     fl_xyplot_gen_ytic( ob );
@@ -1701,8 +1705,6 @@ draw_xyplot( FL_OBJECT * ob )
 }
 
 
-#if 0    /* not used at the moment */
-
 /***************************************
  * For active xyplot only. point (ux,uy) is dragged to a new position.
  *
@@ -1731,7 +1733,7 @@ update_xyplot( FL_OBJECT * ob )
     sp->x[ active ][ n ] = sp->ux;
     sp->y[ active ][ n ] = sp->uy;
 
-    /* Due to possible double buffering switch mapping */
+    /* Due to possible double buffering, switch mapping */
 
     w2s_draw( ob, sp->ux, sp->uy, &x, &y );
 
@@ -1742,8 +1744,6 @@ update_xyplot( FL_OBJECT * ob )
     draw_curve_only( ob );
 }
 
-#endif
-
 
 /***************************************
  * Find the data point the mouse falls on. Since log scale is
@@ -1800,7 +1800,6 @@ find_data( FL_OBJECT * ob,
     /* n overshoots by 1 and we're dependent on that ! */
 
     *n = newi;
-
     return found;
 }
 
@@ -1826,7 +1825,7 @@ handle_mouse( FL_OBJECT * ob,
     float ymin = FL_min( sp->ymin, sp->ymax ),
           ymax = FL_max( sp->ymax, sp->ymin );
 
-    if ( *sp->n == 0 || ! sp->x || ! ( sp->active || sp->inspect ) )
+    if ( *sp->n == 0 || ! sp->x || ( ! sp->active && ! sp->inspect ) )
         return FL_RETURN_NONE;
 
     if ( lmx == mx && lmy == my )
@@ -1839,9 +1838,12 @@ handle_mouse( FL_OBJECT * ob,
     lmx = mx;
     lmy = my;
 
+    mx -= ob->x;
+    my -= ob->y;
+
     /* If the mouse hadn't been on one of the points (or it had been released,
-       in which case sp->inside is negative) check again. Don't do anything
-       yet except changing the way the cursor looks like if we're now on a
+       in which case sp->inside is -1) check again. Don't do anything yet
+       except changing the way the cursor looks like if we're now on a
        point. */
 
     if ( sp->inside <= 0 )
@@ -1968,13 +1970,19 @@ handle_xyplot( FL_OBJECT * ob,
 
     switch ( event )
     {
-        case FL_RESIZED :
-            sp->objx = ob->x;
-            sp->objy = ob->y;
-            break;
-
         case FL_DRAW:
-            draw_xyplot( ob );
+            if ( ob->flpixmap )
+            {
+                sp->objx = ob->flpixmap->x;
+                sp->objy = ob->flpixmap->y;
+            }
+            else
+            {
+                sp->objx = ob->x;
+                sp->objy = ob->y;
+            }
+
+            ( sp->update ? update_xyplot : draw_xyplot )( ob );
             sp->update = 0;
             break;
 
@@ -1982,10 +1990,19 @@ handle_xyplot( FL_OBJECT * ob,
             fl_draw_object_label( ob );
             break;
 
+        case FL_ENTER:
+            sp->objx = ob->x;
+            sp->objy = ob->y;
+            break;
+
         case FL_PUSH:
         case FL_MOTION:
-            if ( key == FL_MBUTTON1 )
-                ret = handle_mouse( ob, mx, my );
+            if ( key != FL_MBUTTON1 )
+                break;
+
+            sp->objx = ob->x;
+            sp->objy = ob->y;
+            ret = handle_mouse( ob, mx, my );
             break;
 
         case FL_RELEASE:
@@ -2149,7 +2166,7 @@ init_spec( FL_OBJECT       * ob,
 
     sp->objx           = ob->x;
     sp->objy           = ob->y;
-    sp->active         = ob->type == FL_ACTIVE_XYPLOT;
+    sp->active         = ob->active;
     sp->key_lsize      = ob->lsize;
     sp->key_lstyle     = ob->lstyle;
     *sp->type          = ob->type;
@@ -2163,6 +2180,7 @@ init_spec( FL_OBJECT       * ob,
     sp->xp++;
     sp->xpactive       = fl_malloc( ( sp->cur_nxp + 3 )
                                     * sizeof *sp->xpactive );
+
     sp->mark_active    = 1;
 }
 
@@ -2184,11 +2202,12 @@ fl_create_xyplot( int          t,
     ob = fl_make_object( FL_XYPLOT, t, x, y, w, h, l, handle_xyplot );
 
     ob->boxtype    = FL_XYPLOT_BOXTYPE;
+    ob->active     = t == FL_ACTIVE_XYPLOT;
     ob->col2       = ob->lcol = FL_BLACK;
     ob->col1       = FL_COL1;
-    ob->lsize      = FL_TINY_SIZE;
+    ob->lsize      = FL_TINY_FONT;
     ob->align      = FL_XYPLOT_ALIGN;
-    ob->spec       = sp = fl_calloc( 1, sizeof *sp );
+    ob->spec       = sp =  fl_calloc( 1, sizeof *sp );
 
     init_spec( ob, sp );
 
@@ -2210,13 +2229,12 @@ fl_add_xyplot( int          t,
                const char * l )
 {
     FL_OBJECT *ob = fl_create_xyplot( t, x, y, w, h, l );
-//    FLI_XYPLOT_SPEC *sp = ob->spec;
 
     fl_add_object( fl_current_form, ob );
 
-    /* Active_xyplot looks a little better in double buffer mode */
+    /* active_xyplot looks a little better in double buffer mode */
 
-//    fl_set_object_dblbuffer( ob, sp->active );
+    fl_set_object_dblbuffer( ob, ob->active );
     return ob;
 }
 
@@ -2302,7 +2320,7 @@ void
 fl_get_xyplot( FL_OBJECT * ob,
                float     * x,
                float     * y,
-               int       * i )
+               int *       i )
 {
     FLI_XYPLOT_SPEC *sp = ob->spec;
 
@@ -2338,8 +2356,8 @@ fl_set_xyplot_maxoverlays( FL_OBJECT * ob,
  ***************************************/
 
 void
-fl_set_xyplot_return( FL_OBJECT    * obj,
-                      unsigned int   when )
+fl_set_xyplot_return( FL_OBJECT * obj,
+                      int         when )
 {
     if ( obj->type == FL_ACTIVE_XYPLOT )
         obj->how_return = when ? FL_RETURN_CHANGED : FL_RETURN_END_CHANGED;
@@ -2404,18 +2422,19 @@ fl_set_xyplot_inspect( FL_OBJECT * ob,
 {
     FLI_XYPLOT_SPEC *sp = ob->spec;
 
-    if ( sp->inspect == yes )
-        return;
-
-    sp->inspect = yes;
-
-    if ( ob->type != FL_ACTIVE_XYPLOT )
+    if ( sp->inspect != yes )
     {
-        /* Work-around, need to get doublebuffer to get inspect work
-           right */
+        ob->active = sp->inspect = yes;
+        if ( ob->type == FL_ACTIVE_XYPLOT )
+            ob->active = 1;
+        else
+        {
+            /* Work-around, need to get doublebuffer to get inspect work
+               right */
 
-//        fl_set_object_dblbuffer( ob, sp->active || sp->inspect );
-        fl_redraw_object( ob );
+            fl_set_object_dblbuffer( ob, sp->active || sp->inspect );
+            fl_redraw_object( ob );
+        }
     }
 }
 
@@ -2683,10 +2702,10 @@ find_ybounds( FLI_XYPLOT_SPEC * sp )
 
 
 /***************************************
- * Overloading would've been nice ...
+ * overloading would'v been nice ...
  ***************************************/
 
-void
+int
 fl_set_xyplot_data_double( FL_OBJECT  * ob,
                            double     * x,
                            double     * y,
@@ -2703,7 +2722,7 @@ fl_set_xyplot_data_double( FL_OBJECT  * ob,
     {
         M_err( "fl_set_xyplot_data_double",
                "%s not an xyplot", ob ? ob->label : "" );
-        return;
+        return FL_BAD_OBJECT;
     }
 #endif
 
@@ -2725,7 +2744,7 @@ fl_set_xyplot_data_double( FL_OBJECT  * ob,
         if ( *sp->x )
             fl_free( *sp->x );
         M_err( "fl_set_xyplot_data_double", "Can't allocate memory" );
-        return;
+        return FL_ALLOC;
     }
 
     extend_screen_data( sp, n );
@@ -2742,13 +2761,14 @@ fl_set_xyplot_data_double( FL_OBJECT  * ob,
     find_ybounds( sp );
 
     fl_redraw_object( ob );
+    return FL_OK;
 }
 
 
 /***************************************
  ***************************************/
 
-void
+int
 fl_set_xyplot_data( FL_OBJECT  * ob,
                     float      * x,
                     float      * y,
@@ -2763,7 +2783,7 @@ fl_set_xyplot_data( FL_OBJECT  * ob,
     if ( ! IsValidClass( ob, FL_XYPLOT ) )
     {
         M_err( "fl_set_xyplot_data", "%s not an xyplot", ob ? ob->label : "" );
-        return;
+        return FL_BAD_OBJECT;
     }
 #endif
 
@@ -2785,7 +2805,7 @@ fl_set_xyplot_data( FL_OBJECT  * ob,
         if ( *sp->x )
             fl_free( *sp->x );
         M_err( "fl_set_xyplot_data", "Can't allocate memory" );
-        return;
+        return FL_ALLOC;
     }
 
     extend_screen_data( sp, n );
@@ -2798,11 +2818,13 @@ fl_set_xyplot_data( FL_OBJECT  * ob,
     find_ybounds( sp );
 
     fl_redraw_object( ob );
+
+    return FL_OK;
 }
 
 
 /***************************************
- * Insert a point after n
+ * insert a point after n
  ***************************************/
 
 void
@@ -3250,7 +3272,7 @@ fl_set_xyplot_interpolate( FL_OBJECT * ob,
     int intpl;
     FLI_XYPLOT_SPEC *sp = ob->spec;
 
-    if ( ! ob || id < 0 || id > sp->maxoverlay )
+    if ( id < 0 || ! ob || id > sp->maxoverlay )
         return;
 
     if ( deg >= 2 && grid <= 0.0 )
@@ -3510,8 +3532,8 @@ w2s_draw( FL_OBJECT * ob,
     float sbx = sp->bxm,
           sby = sp->bym;
 
-    sp->bxm = sp->bx - sp->objx;
-    sp->bym = sp->by - sp->objy;
+    sp->bxm = sp->bx;
+    sp->bym = sp->by;
     fl_xyplot_w2s( ob, wx, wy, sx, sy );
     sp->bxm = sbx;
     sp->bym = sby;
